@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2017 Google Inc. All Rights Reserved.
+# Copyright 2017 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,6 +16,7 @@
 """User errors raised by auth commands."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
 
 from googlecloudsdk.core import exceptions
@@ -35,3 +36,7 @@ class WrongAccountError(exceptions.Error):
 
 class GitCredentialHelperError(exceptions.Error):
   """Raised for issues related to passing auth credentials to Git."""
+
+
+class InvalidIdentityTokenError(exceptions.Error):
+  """Raised when identity token of credential is None."""
