@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2017 Google Inc. All Rights Reserved.
+# Copyright 2017 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"""container builds resource filter expression rewrite backend."""
+"""Cloud Build resource filter expression rewrite backend."""
 
 from __future__ import absolute_import
 from __future__ import division
@@ -55,7 +55,7 @@ _TIME_FIELDS = {
 
 
 class Backend(resource_expr_rewrite.Backend):
-  """Container builds resource filter expression rewrite backend."""
+  """Cloud Build resource filter expression rewrite backend."""
 
   def __init__(self, ongoing=False, **kwargs):
     super(Backend, self).__init__(**kwargs)
