@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2014 Google Inc. All Rights Reserved.
+# Copyright 2014 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -940,7 +940,7 @@ class MultiScopeLister(object):
       holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
       client = holder.client
 
-      request_data = lister.ParseListCommandFlags(args, holder.resources)
+      request_data = lister.ParseMultiScopeFlags(args, holder.resources)
 
       list_implementation = lister.MultiScopeLister(
           client,
