@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2018 Google Inc. All Rights Reserved.
+# Copyright 2018 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,7 +15,9 @@
 """Network endpoint group api client."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 from googlecloudsdk.api_lib.compute import utils as api_utils
 from googlecloudsdk.api_lib.compute.operations import poller
 from googlecloudsdk.api_lib.util import waiter
@@ -31,7 +33,7 @@ class NetworkEndpointGroupsClient(object):
     self.resources = resources
     self._service = self.client.apitools_client.networkEndpointGroups
 
-  def Create(self, neg_ref, neg_type, network_endpoint_type, default_port=None,
+  def Create(self, neg_ref, network_endpoint_type, default_port=None,
              network=None, subnet=None):
     """Creates a network endpoint group."""
     network_uri = None
@@ -48,18 +50,15 @@ class NetworkEndpointGroupsClient(object):
           collection='compute.subnetworks')
       subnet_uri = subnet_ref.SelfLink()
 
-    type_enum = self.messages.NetworkEndpointGroup.TypeValueValuesEnum
     endpoint_type_enum = (self.messages.NetworkEndpointGroup
                           .NetworkEndpointTypeValueValuesEnum)
     network_endpoint_group = self.messages.NetworkEndpointGroup(
         name=neg_ref.Name(),
-        type=arg_utils.ChoiceToEnum(neg_type, type_enum),
-        networkEndpointType=arg_utils.ChoiceToEnum(
-            network_endpoint_type, endpoint_type_enum),
-        loadBalancer=self.messages.NetworkEndpointGroupLbNetworkEndpointGroup(
-            defaultPort=default_port,
-            network=network_uri,
-            subnetwork=subnet_uri))
+        networkEndpointType=arg_utils.ChoiceToEnum(network_endpoint_type,
+                                                   endpoint_type_enum),
+        defaultPort=default_port,
+        network=network_uri,
+        subnetwork=subnet_uri)
     request = self.messages.ComputeNetworkEndpointGroupsInsertRequest(
         networkEndpointGroup=network_endpoint_group,
         project=neg_ref.project,
