@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2018 Google Inc. All Rights Reserved.
+# Copyright 2018 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -48,7 +48,8 @@ class Client(object):
             description=None,
             labels=None,
             private_visibility_config=None,
-            forwarding_config=None):
+            forwarding_config=None,
+            peering_config=None):
     """Managed Zones Update Request."""
     zone = self.messages.ManagedZone(
         name=zone_ref.Name(),
@@ -59,6 +60,8 @@ class Client(object):
       zone.privateVisibilityConfig = private_visibility_config
     if forwarding_config:
       zone.forwardingConfig = forwarding_config
+    if peering_config:
+      zone.peeringConfig = peering_config
     return self._service.Patch(
         self.messages.DnsManagedZonesPatchRequest(
             managedZoneResource=zone,
