@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2017 Google Inc. All Rights Reserved.
+# Copyright 2017 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,6 +18,7 @@
 from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
+
 import json
 import re
 
@@ -342,7 +343,7 @@ def PushMultipleServiceConfigFiles(service_name, config_files, is_async,
   for diagnostic in diagnostics:
     kind = diagnostic.get('kind', '').upper()
     logger = log.error if kind == 'ERROR' else log.warning
-    msg = '{l}: {m}'.format(
+    msg = '{l}: {m}\n'.format(
         l=diagnostic.get('location'), m=diagnostic.get('message'))
     logger(msg)
 
@@ -387,12 +388,14 @@ def PushOpenApiServiceConfig(
                                         validate_only=validate_only)
 
 
-def CreateServiceIfNew(service_name, project):
-  """Creates a Service resource if it does not already exist.
+def DoesServiceExist(service_name):
+  """Check if a service resource exists.
 
   Args:
-    service_name: name of the service to be returned or created.
-    project: the project Id
+    service_name: name of the service to check if exists.
+
+  Returns:
+    Whether or not the service exists.
   """
   messages = GetMessagesModule()
   client = GetClientInstance()
@@ -405,12 +408,26 @@ def CreateServiceIfNew(service_name, project):
           apitools_exceptions.HttpNotFoundError):
     # Older versions of service management backend return a 404 when service is
     # new, but more recent versions return a 403. Check for either one for now.
-    # create service
-    create_request = messages.ManagedService(
-        serviceName=service_name,
-        producerProjectId=project,
-    )
-    client.services.Create(create_request)
+    return False
+  else:
+    return True
+
+
+def CreateService(service_name, project):
+  """Creates a Service resource.
+
+  Args:
+    service_name: name of the service to be created.
+    project: the project Id
+  """
+  messages = GetMessagesModule()
+  client = GetClientInstance()
+  # create service
+  create_request = messages.ManagedService(
+      serviceName=service_name,
+      producerProjectId=project,
+  )
+  client.services.Create(create_request)
 
 
 def GetByteStringFromFingerprint(fingerprint):
@@ -466,12 +483,12 @@ def ProcessOperationResult(result, is_async=False):
     cmd = OP_WAIT_CMD.format(op.get('name'))
     log.status.Print('Asynchronous operation is in progress... '
                      'Use the following command to wait for its '
-                     'completion:\n {0}'.format(cmd))
+                     'completion:\n {0}\n'.format(cmd))
   else:
     cmd = OP_DESCRIBE_CMD.format(op.get('name'))
     log.status.Print('Operation finished successfully. '
                      'The following command can describe '
-                     'the Operation details:\n {0}'.format(cmd))
+                     'the Operation details:\n {0}\n'.format(cmd))
   return op
 
 
