@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2017 Google Inc. All Rights Reserved.
+# Copyright 2017 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,9 @@
 """Exceptions raised by Testing API libs or commands."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 from googlecloudsdk.api_lib.firebase.test import exit_code
 from googlecloudsdk.calliope import exceptions as calliope_exceptions
 from googlecloudsdk.core import exceptions as core_exceptions
@@ -99,13 +101,12 @@ class InvalidDimensionNameError(TestingError):
         "['model', 'version', 'locale', 'orientation']".format(d=dim_name))
 
 
-class InvalidIosDimensionNameError(TestingError):
-  """An invalid ios test matrix dimension name was encountered."""
+class XcodeVersionNotFoundError(TestingError):
+  """Failed to find an Xcode version in the test environment catalog."""
 
-  def __init__(self, dim_name):
-    super(InvalidIosDimensionNameError,
-          self).__init__("'{d}' is not a valid dimension name. Must be one of: "
-                         "['model', 'version']".format(d=dim_name))
+  def __init__(self, version):
+    super(XcodeVersionNotFoundError, self).__init__(
+        "'{v}' is not a supported Xcode version".format(v=version))
 
 
 class TestExecutionNotFoundError(TestingError):
