@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2017 Google Inc. All Rights Reserved.
+# Copyright 2017 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -140,6 +140,11 @@ def _ErrorFromInvalidMatrix(matrix):
           'The app declares one or more permissions that are not allowed',
       enum_values.INVALID_ROBO_DIRECTIVES:
           'Cannot have multiple robo-directives with the same resource name',
+      enum_values.INVALID_DIRECTIVE_ACTION:
+          'Robo Directive includes at least one invalid action definition.',
+      enum_values.INVALID_RESOURCE_NAME:
+          'Robo Directive resource name contains invalid characters: ":" '
+          ' (colon) or " " (space)',
       enum_values.TEST_LOOP_INTENT_FILTER_NOT_FOUND:
           'The app does not have a correctly formatted game-loop intent filter',
       enum_values.SCENARIO_LABEL_NOT_DECLARED:
