@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2014 Google Inc. All Rights Reserved.
+# Copyright 2014 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -120,6 +120,52 @@ def AddBucketLocationArg(parser, required, help_string):
       '--location', required=required, metavar='LOCATION', help=help_string)
 
 
+def GetProjectResource():
+  """Returns the resource for the current project."""
+  return resources.REGISTRY.Parse(
+      properties.VALUES.core.project.Get(required=True),
+      collection='cloudresourcemanager.projects')
+
+
+def GetOrganizationResource(organization):
+  """Returns the resource for the organization.
+
+  Args:
+    organization: organization.
+
+  Returns:
+    The resource.
+  """
+  return resources.REGISTRY.Parse(
+      organization, collection='cloudresourcemanager.organizations')
+
+
+def GetFolderResource(folder):
+  """Returns the resource for the folder.
+
+  Args:
+    folder: folder.
+
+  Returns:
+    The resource.
+  """
+  return folders.FoldersRegistry().Parse(
+      folder, collection='cloudresourcemanager.folders')
+
+
+def GetBillingAccountResource(billing_account):
+  """Returns the resource for the billing_account.
+
+  Args:
+    billing_account: billing account.
+
+  Returns:
+    The resource.
+  """
+  return resources.REGISTRY.Parse(
+      billing_account, collection='cloudbilling.billingAccounts')
+
+
 def GetParentResourceFromArgs(args):
   """Returns the parent resource derived from the given args.
 
@@ -130,21 +176,13 @@ def GetParentResourceFromArgs(args):
     The parent resource.
   """
   if args.organization:
-    return resources.REGISTRY.Parse(
-        args.organization,
-        collection='cloudresourcemanager.organizations')
+    return GetOrganizationResource(args.organization)
   elif args.folder:
-    return folders.FoldersRegistry().Parse(
-        args.folder,
-        collection='cloudresourcemanager.folders')
+    return GetFolderResource(args.folder)
   elif args.billing_account:
-    return resources.REGISTRY.Parse(
-        args.billing_account,
-        collection='cloudbilling.billingAccounts')
+    return GetBillingAccountResource(args.billing_account)
   else:
-    return resources.REGISTRY.Parse(
-        properties.VALUES.core.project.Get(required=True),
-        collection='cloudresourcemanager.projects')
+    return GetProjectResource()
 
 
 def GetParentFromArgs(args):
@@ -267,12 +305,13 @@ def ExtractLogId(log_resource):
   return log_id.replace('%2F', '/')
 
 
-def PrintPermissionInstructions(destination, writer_identity):
+def PrintPermissionInstructions(destination, writer_identity, is_dlp_sink):
   """Prints a message to remind the user to set up permissions for a sink.
 
   Args:
     destination: the sink destination (either bigquery or cloud storage).
     writer_identity: identity to which to grant write access.
+    is_dlp_sink: whether or not the sink is DLP enabled.
   """
   if writer_identity:
     grantee = '`{0}`'.format(writer_identity)
@@ -281,14 +320,18 @@ def PrintPermissionInstructions(destination, writer_identity):
 
   # TODO(b/31449674): if ladder needs test coverage
   if destination.startswith('bigquery'):
-    sdk_log.status.Print('Please remember to grant {0} '
-                         'the WRITER role on the dataset.'.format(grantee))
+    sdk_log.status.Print('Please remember to grant {0} the BigQuery Data '
+                         'Editor role on the dataset.'.format(grantee))
   elif destination.startswith('storage'):
-    sdk_log.status.Print('Please remember to grant {0} '
-                         'full-control access to the bucket.'.format(grantee))
+    sdk_log.status.Print('Please remember to grant {0} the Storage Object '
+                         'Creator role on the bucket.'.format(grantee))
   elif destination.startswith('pubsub'):
-    sdk_log.status.Print('Please remember to grant {0} Pub/Sub '
-                         'Publisher role to the topic.'.format(grantee))
+    sdk_log.status.Print('Please remember to grant {0} the Pub/Sub Publisher '
+                         'role on the topic.'.format(grantee))
+  if is_dlp_sink:
+    sdk_log.status.Print('Also remember to grant {0} DLP User and DLP Reader '
+                         'roles on the project that owns the sink '
+                         'destination.'.format(grantee))
   sdk_log.status.Print('More information about sinks can be found at https://'
                        'cloud.google.com/logging/docs/export/configure_export')
 
