@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2016 Google Inc. All Rights Reserved.
+# Copyright 2016 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,11 +13,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """Utilities for dealing with ML jobs API."""
+
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 from apitools.base.py import encoding
 from apitools.base.py import list_pager
 from googlecloudsdk.api_lib.util import apis
+from googlecloudsdk.command_lib.util.apis import arg_utils
 from googlecloudsdk.core import exceptions
 from googlecloudsdk.core import properties
 from googlecloudsdk.core import resources
@@ -120,7 +124,8 @@ class JobsClient(object):
                        user_args=None,
                        runtime_version=None,
                        python_version=None,
-                       labels=None):
+                       labels=None,
+                       custom_train_server_config=None):
     """Builds a Cloud ML Engine Job from a config file and/or flag values.
 
     Args:
@@ -141,11 +146,14 @@ class JobsClient(object):
         python_version: the Python version in which to run the job (overrides
           yaml file)
         labels: Job.LabelsValue, the Cloud labels for the job
+        custom_train_server_config: jobs_util.CustomTrainingInputServerConfig,
+          configuration object for custom server parameters.
     Returns:
         A constructed Job object.
     """
     job = self.job_class()
 
+    # TODO(b/123467089): Remove yaml file loading here, only parse data objects
     if path:
       data = yaml.load_path(path)
       if data:
@@ -173,6 +181,28 @@ class JobsClient(object):
       if value is not None:
         setattr(job.trainingInput, field_name, value)
 
+    if custom_train_server_config:
+      for field_name, value in custom_train_server_config.GetFieldMap().items():
+        if value is not None:
+          if field_name.endswith('Config'):
+            if value['imageUri']:
+              arg_utils.SetFieldInMessage(job,
+                                          'trainingInput.{}.imageUri'.format(
+                                              field_name),
+                                          value['imageUri'])
+            if value['acceleratorConfig']['type']:
+              arg_utils.SetFieldInMessage(
+                  job,
+                  'trainingInput.{}.acceleratorConfig.type'.format(field_name),
+                  value['acceleratorConfig']['type'])
+            if value['acceleratorConfig']['count']:
+              arg_utils.SetFieldInMessage(
+                  job,
+                  'trainingInput.{}.acceleratorConfig.count'.format(field_name),
+                  value['acceleratorConfig']['count'])
+          else:
+            setattr(job.trainingInput, field_name, value)
+
     return job
 
   def BuildBatchPredictionJob(self,
@@ -187,6 +217,7 @@ class JobsClient(object):
                               runtime_version=None,
                               max_worker_count=None,
                               batch_size=None,
+                              signature_name=None,
                               labels=None,
                               accelerator_count=None,
                               accelerator_type=None):
@@ -203,7 +234,8 @@ class JobsClient(object):
         region: compute region in which to run the job
         runtime_version: the runtime version in which to run the job
         max_worker_count: int, the maximum number of workers to use
-        batch_size: str, the number of records per batch sent to Tensorflow
+        batch_size: int, the number of records per batch sent to Tensorflow
+        signature_name: str, name of input/output signature in the TF meta graph
         labels: Job.LabelsValue, the Cloud labels for the job
         accelerator_count: int, The number of accelerators to attach to the
            machines
@@ -246,6 +278,9 @@ class JobsClient(object):
           params={'projectsId': project_id})
       prediction_input.modelName = model_ref.RelativeName()
 
+    if signature_name:
+      prediction_input.signatureName = signature_name
+
     return self.job_class(
         jobId=job_name,
         predictionInput=prediction_input,
