@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2018 Google Inc. All Rights Reserved.
+# Copyright 2018 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -31,19 +31,32 @@ import six
 REGION_LABEL = 'cloud.googleapis.com/location'
 
 
-def InitializedInstance(msg_cls):
+def InitializedInstance(msg_cls, excluded_fields=None):
   """Produce an instance of msg_cls, with all sub-messages initialized.
 
   Args:
     msg_cls: A message-class to be instantiated.
+    excluded_fields: [str], List of field names to exclude from instantiation.
   Returns:
     An instance of the given class, with all fields initialized blank objects.
   """
+  def Instance(field):
+    if field.repeated:
+      return []
+    return InitializedInstance(field.message_type, excluded_fields)
+
+  def IncludeField(field):
+    if not isinstance(field, messages.MessageField):
+      return False
+
+    if excluded_fields and field.name in excluded_fields:
+      return False
+
+    return True
+
   args = {
-      field.name: ([] if field.repeated else
-                   InitializedInstance(field.message_type))
-      for field in msg_cls.all_fields()
-      if isinstance(field, messages.MessageField)
+      field.name: Instance(field) for field in msg_cls.all_fields()
+      if IncludeField(field)
   }
   return msg_cls(**args)
 
@@ -62,6 +75,8 @@ class KubernetesObject(object):
   """
 
   READY_CONDITION = 'Ready'
+  # Message fields to exclude from instantiation of this object.
+  FIELD_BLACKLIST = []
 
   @classmethod
   def SpecOnly(cls, spec, messages_mod):
@@ -78,7 +93,14 @@ class KubernetesObject(object):
       a new k8s_object with only the given spec.
     """
     msg_cls = getattr(messages_mod, cls.KIND)
-    return cls(msg_cls(spec=spec), messages_mod, spec_only=True)
+    return cls(msg_cls(spec=spec), messages_mod)
+
+  @classmethod
+  def Template(cls, template, messages_mod):
+    """Wrap a template object: spec and metadata only, no status."""
+    msg_cls = getattr(messages_mod, cls.KIND)
+    return cls(msg_cls(spec=template.spec, metadata=template.metadata),
+               messages_mod)
 
   @classmethod
   def New(cls, client, namespace):
@@ -96,7 +118,8 @@ class KubernetesObject(object):
     """
     api_version = '{}/{}'.format(cls.API_CATEGORY, getattr(client, '_VERSION'))
     messages_mod = client.MESSAGES_MODULE
-    ret = InitializedInstance(getattr(messages_mod, cls.KIND))
+    ret = InitializedInstance(getattr(messages_mod, cls.KIND),
+                              cls.FIELD_BLACKLIST)
     try:
       ret.kind = cls.KIND
       ret.apiVersion = api_version
@@ -107,19 +130,18 @@ class KubernetesObject(object):
     ret.metadata.namespace = namespace
     return cls(ret, messages_mod)
 
-  def __init__(self, to_wrap, messages_mod, spec_only=False):
+  def __init__(self, to_wrap, messages_mod):
     if not isinstance(to_wrap, getattr(messages_mod, self.KIND)):
       raise ValueError('Oops, trying to wrap wrong kind of message')
     self._m = to_wrap
     self._messages = messages_mod
-    self._spec_only = spec_only
 
   def MessagesModule(self):
     """Return the messages module."""
     return self._messages
 
   def AssertFullObject(self):
-    if self._spec_only:
+    if not self._m.metadata:
       raise ValueError('This instance is spec-only.')
 
   # Access the "raw" k8s message parts. When subclasses want to allow mutability
@@ -178,6 +200,11 @@ class KubernetesObject(object):
     self.AssertFullObject()
     return self._m.metadata.resourceVersion
 
+  @property
+  def self_link(self):
+    self.AssertFullObject()
+    return self._m.metadata.selfLink.lstrip('/')
+
   @property
   def region(self):
     self.AssertFullObject()
@@ -215,17 +242,7 @@ class KubernetesObject(object):
   @property
   def labels(self):
     self.AssertFullObject()
-
-    if not self._m.metadata.labels:
-      self._m.metadata.labels = self._messages.ObjectMeta.LabelsValue(
-          additionalProperties=[])
-
-    return ListAsDictionaryWrapper(
-        self._m.metadata.labels.additionalProperties,
-        self._messages.ObjectMeta.LabelsValue.AdditionalProperty,
-        key_field='key',
-        value_field='value',
-    )
+    return LabelsFromMetadata(self._messages, self._m.metadata)
 
   @property
   def ready(self):
@@ -275,6 +292,16 @@ def AnnotationsFromMetadata(messages_mod, metadata):
       value_field='value')
 
 
+def LabelsFromMetadata(messages_mod, metadata):
+  if not metadata.labels:
+    metadata.labels = messages_mod.ObjectMeta.LabelsValue()
+  return ListAsDictionaryWrapper(
+      metadata.labels.additionalProperties,
+      messages_mod.ObjectMeta.LabelsValue.AdditionalProperty,
+      key_field='key',
+      value_field='value')
+
+
 class LazyListWrapper(collections.MutableSequence):
   """Wraps a list that does not exist at object creation time.
 
