@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2018 Google Inc. All Rights Reserved.
+# Copyright 2018 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,6 +20,7 @@ from __future__ import unicode_literals
 
 from googlecloudsdk.api_lib.run import configuration
 from googlecloudsdk.api_lib.run import k8s_object
+from googlecloudsdk.api_lib.run import revision
 
 
 ENDPOINT_VISIBILITY = 'serving.knative.dev/visibility'
@@ -34,6 +35,9 @@ class Service(k8s_object.KubernetesObject):
   """
   API_CATEGORY = 'serving.knative.dev'
   KIND = 'Service'
+  # Field names that are present in Cloud Run messages, but should not be
+  # initialized because they aren't supported by the control plane yet.
+  FIELD_BLACKLIST = ['manual', 'release', 'template']
 
   @classmethod
   def New(cls, client, namespace, private_endpoint=None):
@@ -51,10 +55,6 @@ class Service(k8s_object.KubernetesObject):
     ret = super(Service, cls).New(client, namespace)
     # We're in oneOf territory, set the other to None for now.
     ret.spec.pinned = None
-    # The build is also a oneOf
-    # TODO(b/112662240): Remove conditional once this field is public
-    if hasattr(ret.configuration.spec, 'build'):
-      ret.configuration.spec.build = None
 
     if private_endpoint:
       ret.labels[ENDPOINT_VISIBILITY] = CLUSTER_LOCAL
@@ -67,12 +67,36 @@ class Service(k8s_object.KubernetesObject):
     ret.configuration.container.securityContext = None
     return ret
 
+  def _EnsureRevisionMeta(self):
+    revision_meta = self.spec.revisionTemplate.metadata
+    if revision_meta is None:
+      revision_meta = self._messages.ObjectMeta()
+      self.spec.revisionTemplate.metadata = revision_meta
+    return revision_meta
+
   @property
   def configuration(self):
     """Configuration (configuration.Configuration) of the service, if any."""
     options = (self._m.spec.pinned, self._m.spec.runLatest)
     ret = next((o.configuration for o in options if o is not None), None)
-    return configuration.Configuration.SpecOnly(ret, self._messages)
+    if ret:
+      return configuration.Configuration.SpecOnly(ret, self._messages)
+    return None
+
+  @property
+  def template(self):
+    if self.configuration:
+      return self.configuration.template
+    else:
+      ret = revision.Revision.Template(
+          self.spec.template, self.MessagesModule())
+      if not ret.metadata:
+        ret.metadata = self.MessagesModule().ObjectMeta()
+      return ret
+
+  @property
+  def revision_labels(self):
+    return self.template.labels
 
   @property
   def latest_created_revision(self):
@@ -98,4 +122,12 @@ class Service(k8s_object.KubernetesObject):
       return '!'
     return super(Service, self).ready_symbol
 
+  @property
+  def last_modifier(self):
+    return self.annotations.get(u'serving.knative.dev/lastModifier')
 
+  @property
+  def last_transition_time(self):
+    return next((c.lastTransitionTime
+                 for c in self.status.conditions
+                 if c.type == u'Ready'), None)
