@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2016 Google Inc. All Rights Reserved.
+# Copyright 2016 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -150,6 +150,12 @@ def StartCloudSqlProxy(instance, port, seconds_to_timeout=10):
   return _WaitForProxyToStart(proxy_process, port, seconds_to_timeout)
 
 
+def IsInstanceV1(instance):
+  """Returns a boolean indicating if the database instance is first gen."""
+  return (instance.backendType == 'FIRST_GEN' or
+          (instance.settings and instance.settings.tier.startswith('D')))
+
+
 def IsInstanceV2(instance):
   """Returns a boolean indicating if the database instance is second gen."""
   return instance.backendType == 'SECOND_GEN'
