@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2015 Google Inc. All Rights Reserved.
+# Copyright 2015 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -84,7 +84,7 @@ class DevSiteGenerator(walker.Walker):
     self._toc_root.write('- title: "gcloud Reference"\n')
     self._toc_root.write('  path: %s\n' % self._REFERENCE)
     self._toc_root.write('  section:\n')
-    self._toc_main = None  # type: file
+    self._toc_main = None
 
   def Visit(self, node, parent, is_group):
     """Updates the TOC and Renders a DevSite doc for each node in the CLI tree.
@@ -408,7 +408,7 @@ class ManPageGenerator(DocumentGenerator):
 
 
 class LinterGenerator(DocumentGenerator):
-  """Generates linter files with suffix .txt in an output directory."""
+  """Generates linter files with suffix .json in an output directory."""
 
   def __init__(self, cli, directory, hidden=False, progress_callback=None,
                restrict=None):
@@ -428,7 +428,7 @@ class LinterGenerator(DocumentGenerator):
     """
 
     super(LinterGenerator, self).__init__(
-        cli, directory=directory, style='linter', suffix='.txt')
+        cli, directory=directory, style='linter', suffix='.json')
 
 
 class CommandTreeGenerator(walker.Walker):
