@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2014 Google Inc. All Rights Reserved.
+# Copyright 2014 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -128,7 +128,8 @@ GLOBAL_REGIONAL_MULTI_BACKEND_SERVICE_ARG = compute_flags.ResourceArgument(
     global_collection='compute.backendServices')
 
 
-def BackendServiceArgumentForUrlMap(required=True, include_alpha=False):
+def BackendServiceArgumentForUrlMap(required=True,
+                                    include_l7_internal_load_balancing=False):
   return compute_flags.ResourceArgument(
       resource_name='backend service',
       name='--default-service',
@@ -136,7 +137,7 @@ def BackendServiceArgumentForUrlMap(required=True, include_alpha=False):
       completer=BackendServicesCompleter,
       global_collection='compute.backendServices',
       regional_collection='compute.regionBackendServices'
-      if include_alpha else None,
+      if include_l7_internal_load_balancing else None,
       short_help=(
           'A backend service that will be used for requests for which this '
           'URL map has no mappings.'),
@@ -184,11 +185,11 @@ def BackendServiceArgumentForTargetTcpProxy(required=True):
         """)
 
 
-def AddLoadBalancingScheme(parser, include_alpha=False):
+def AddLoadBalancingScheme(parser, include_l7_ilb=False):
   parser.add_argument(
       '--load-balancing-scheme',
-      choices=['INTERNAL', 'EXTERNAL'] +
-      (['INTERNAL_MANAGED', 'INTERNAL_SELF_MANAGED'] if include_alpha else []),
+      choices=['INTERNAL', 'EXTERNAL', 'INTERNAL_SELF_MANAGED'] +
+      (['INTERNAL_MANAGED'] if include_l7_ilb else []),
       type=lambda x: x.replace('-', '_').upper(),
       default='EXTERNAL',
       help='Specifies if this is internal or external load balancer.')
@@ -328,7 +329,7 @@ def AddCacheKeyQueryStringList(parser):
       """)
 
 
-def HealthCheckArgument(required=False, include_alpha=False):
+def HealthCheckArgument(required=False, support_regional_health_check=False):
   return compute_flags.ResourceArgument(
       resource_name='health check',
       name='--health-checks',
@@ -337,7 +338,7 @@ def HealthCheckArgument(required=False, include_alpha=False):
       required=required,
       global_collection='compute.healthChecks',
       regional_collection='compute.regionHealthChecks'
-      if include_alpha else None,
+      if support_regional_health_check else None,
       short_help="""\
       Specifies a list of health check objects for checking the health of
       the backend service. Currently at most one health check can be specified.
@@ -345,7 +346,7 @@ def HealthCheckArgument(required=False, include_alpha=False):
       service.
       """,
       region_explanation=compute_flags.REGION_PROPERTY_EXPLANATION
-      if include_alpha else None)
+      if support_regional_health_check else None)
 
 
 def HttpHealthCheckArgument(required=False):
@@ -443,19 +444,33 @@ def AddSessionAffinity(parser, target_pools=False, hidden=False):
   if not target_pools:
     choices.update({
         'GENERATED_COOKIE': (
-            '(Applicable if load-balancing scheme is external) Route requests '
-            'to instances based on the contents of the "GCLB" '
-            'cookie set by the load balancer.'),
+            '(Applicable if `--load-balancing-scheme` is '
+            '`INTERNAL_SELF_MANAGED` or `EXTERNAL`) '
+            'If the `--load-balancing-scheme` is `EXTERNAL`, routes '
+            'requests to backend VMs or endpoints in a NEG, based on the '
+            'contents of the "GCLB" cookie set by the load balancer. Only '
+            'applicable when --protocol is HTTP, HTTPS, or HTTP2. '
+            'If the `--load-balancing-scheme` is `INTERNAL_SELF_MANAGED`, '
+            'routes requests to backend VMs or endpoints in a NEG, '
+            'based on the contents of the a cookie set by Traffic Director.'),
         'CLIENT_IP_PROTO': (
-            '(Applicable if load-balancing scheme is internal) '
+            '(Applicable if `--load-balancing-scheme` is `INTERNAL`) '
             'Connections from the same client IP with the same IP '
-            'protocol will go to the same VM in the pool while that VM remains'
+            'protocol will go to the same backend VM while that VM remains'
             ' healthy.'),
         'CLIENT_IP_PORT_PROTO': (
-            '(Applicable if load-balancing scheme is internal) Connections from'
-            ' the same client IP with the same IP protocol and '
-            'port will go to the same VM in the backend while that VM remains '
+            '(Applicable if `--load-balancing-scheme` is `INTERNAL`) '
+            'Connections from the same client IP with the same IP protocol and '
+            'port will go to the same backend VM while that VM remains '
             'healthy.'),
+        'HTTP_COOKIE': (
+            '(Applicable if `--load-balancing-scheme` is '
+            '`INTERNAL_SELF_MANAGED`) Route requests to backend VMs or '
+            'endpoints in a NEG based on an HTTP cookie set by the client.'),
+        'HEADER_FIELD': (
+            '(Applicable if `--load-balancing-scheme` is '
+            '`INTERNAL_SELF_MANAGED`) Route requests to backend VMs or'
+            ' endpoints in a NEG based on an HTTP header.'),
     })
   help_str = 'The type of TCP session affinity to use. Not supported for UDP.'
   parser.add_argument(
