@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2017 Google Inc. All Rights Reserved.
+# Copyright 2017 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -188,8 +188,8 @@ def AddReservationArgGroup(parser):
 
   reservations_manage_group.add_argument(
       '--reservations-from-file',
-      type=arg_parsers.BufferedFileInput(),
-      help='The path to a YAML file of multiple reservations\' configuration.')
+      type=arg_parsers.FileContents(),
+      help='Path to a YAML file of multiple reservations\' configuration.')
 
   single_reservation_group = reservations_manage_group.add_argument_group(
       help='Manage the reservation to be created with the commitment.')
