@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2017 Google Inc. All Rights Reserved.
+# Copyright 2017 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,7 +15,9 @@
 """Helpers for running commands external to gcloud."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 import subprocess
 from googlecloudsdk.command_lib.compute import ssh_utils
 from googlecloudsdk.command_lib.util.ssh import containers
@@ -107,8 +109,9 @@ def RunSSHCommandToInstance(command_list,
   Raises:
     ssh.CommandError: there was an error running a SSH command
   """
-  external_ip_address = ssh_utils.GetExternalIPAddress(instance)
-  remote = ssh.Remote(external_ip_address, user)
+  external_address = ssh_utils.GetExternalIPAddress(instance)
+  internal_address = ssh_utils.GetInternalIpAddress(instance)
+  remote = ssh.Remote(external_address, user)
 
   identity_file = None
   options = None
@@ -116,7 +119,8 @@ def RunSSHCommandToInstance(command_list,
     identity_file = ssh_helper.keys.key_file
     options = ssh_helper.GetConfig(ssh_utils.HostKeyAlias(instance),
                                    args.strict_host_key_checking)
-  extra_flags = ssh.ParseAndSubstituteSSHFlags(args, remote, user)
+  extra_flags = ssh.ParseAndSubstituteSSHFlags(args, remote, external_address,
+                                               internal_address)
   remainder = []
 
   remote_command = containers.GetRemoteCommand(None, command_list)
