@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2016 Google Inc. All Rights Reserved.
+# Copyright 2016 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,12 +16,14 @@
 """Flags and helpers for the compute disks commands."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 from googlecloudsdk.command_lib.compute import completers as compute_completers
 from googlecloudsdk.command_lib.compute import flags as compute_flags
 
 _DETAILED_SOURCE_SNAPSHOT_HELP = """\
-      A source snapshot used to create the disks. It is safe to
+      Source snapshot used to create the disks. It is safe to
       delete a snapshot after a disk has been created from the
       snapshot. In such cases, the disks will no longer reference
       the deleted snapshot. To get a list of snapshots in your
@@ -66,7 +68,7 @@ class SnapshotsCompleter(compute_completers.ListCommandCompleter):
         **kwargs)
 
 
-def MakeDiskArg(plural):
+def MakeDiskArgZonal(plural):
   return compute_flags.ResourceArgument(
       resource_name='disk',
       completer=compute_completers.DisksCompleter,
@@ -76,7 +78,7 @@ def MakeDiskArg(plural):
       zone_explanation=compute_flags.ZONE_PROPERTY_EXPLANATION)
 
 
-def MakeDiskArgZonalOrRegional(plural):
+def MakeDiskArg(plural):
   return compute_flags.ResourceArgument(
       resource_name='disk',
       completer=compute_completers.DisksCompleter,
@@ -94,5 +96,5 @@ SOURCE_SNAPSHOT_ARG = compute_flags.ResourceArgument(
     plural=False,
     required=False,
     global_collection='compute.snapshots',
-    short_help='A source snapshot used to create the disks.',
+    short_help='Source snapshot used to create the disks.',
     detailed_help=_DETAILED_SOURCE_SNAPSHOT_HELP,)
