@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2016 Google Inc. All Rights Reserved.
+# Copyright 2016 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -48,7 +48,7 @@ STAGE_TYPES = (msgs.Role.StageValueValuesEnum)
 
 SERVICE_ACCOUNTS_COLLECTION = 'iam.projects.serviceAccounts'
 
-SERVICE_ACCOUNT_FORMAT = 'table(displayName:label=NAME, email)'
+SERVICE_ACCOUNT_FORMAT = 'table(displayName:label=NAME, email, disabled)'
 SERVICE_ACCOUNT_KEY_FORMAT = """
     table(
         name.scope(keys):label=KEY_ID,
@@ -104,9 +104,10 @@ Examples: `user:test-user@gmail.com`, `group:admins@example.com`,
 `domain:example.domain.com`.
 
 Can also be one of the following special values:
-* `allUsers` - anyone who is on the internet, with or without a Google account.
-* `allAuthenticatedUsers` - anyone who is authenticated with a Google account or
-   a service account.
+* `allUsers` - Special identifier that represents anyone who is on the internet,
+   with or without a Google account.
+* `allAuthenticatedUsers` - Special identifier that represents anyone who is
+   authenticated with a Google account or a service account.
       """
   ).format(verb=verb)
   parser.add_argument('--member', required=required, help=help_str)
@@ -164,7 +165,7 @@ To see available fields, see the help for `--condition`."""
 
   condition_group.add_argument(
       '--condition-from-file',
-      type=arg_parsers.BufferedFileInput(),
+      type=arg_parsers.FileContents(),
       help=help_str_condition_from_file)
 
 
@@ -193,7 +194,7 @@ conditions."""
 
   condition_group.add_argument(
       '--condition-from-file',
-      type=arg_parsers.BufferedFileInput(),
+      type=arg_parsers.FileContents(),
       help=help_str_condition_from_file)
 
   condition_group.add_argument(
@@ -639,6 +640,14 @@ def _PolicyContainsCondition(policy):
   return False
 
 
+def BindingInPolicy(policy, member, role):
+  """Returns True if policy contains the specified binding."""
+  for binding in policy.bindings:
+    if binding.role == role and member in binding.members:
+      return True
+  return False
+
+
 def RemoveBindingFromIamPolicy(policy, member, role):
   """Given an IAM policy, remove bindings as specified by the args.
 
