@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2017 Google Inc. All Rights Reserved.
+# Copyright 2017 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -195,7 +195,8 @@ def AddCiphertextFileFlag(parser, help_action):
 def AddSignatureFileFlag(parser, help_action):
   parser.add_argument(
       '--signature-file',
-      help='Path to the signature file {}.'.format(help_action))
+      help='Path to the signature file {}.'.format(help_action),
+      required=True)
 
 
 def AddInputFileFlag(parser, help_action):
