@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2017 Google Inc. All Rights Reserved.
+# Copyright 2017 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -143,7 +143,7 @@ def AddPushConfigFlags(parser, track, required=False):
       '--push-endpoint', required=required,
       help='A URL to use as the endpoint for this subscription. This will '
            'also automatically set the subscription type to PUSH.')
-  if track in [base.ReleaseTrack.ALPHA]:
+  if track in [base.ReleaseTrack.BETA, base.ReleaseTrack.ALPHA]:
     parser.add_argument(
         '--push-auth-service-account',
         required=False,
@@ -228,16 +228,15 @@ def AddSubscriptionSettingsFlags(parser, track, is_update=False):
   AddAckDeadlineFlag(parser)
   AddPushConfigFlags(parser, track)
   AddMessageRetentionFlags(parser, is_update)
-  if track in [base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA]:
-    parser.add_argument(
-        '--expiration-period',
-        type=ParseExpirationPeriodWithNeverSentinel,
-        help="""The subscription will expire if it is inactive for the given
-            period. Valid values are strings of the form INTEGER[UNIT], where
-            UNIT is one of "s", "m", "h", and "d" for seconds, minutes, hours,
-            and days, respectively. If the unit is omitted, seconds is
-            assumed. This flag additionally accepts the special value "never" to
-            indicate that the subscription will never expire.""")
+  parser.add_argument(
+      '--expiration-period',
+      type=ParseExpirationPeriodWithNeverSentinel,
+      help="""The subscription will expire if it is inactive for the given
+          period. Valid values are strings of the form INTEGER[UNIT], where
+          UNIT is one of "s", "m", "h", and "d" for seconds, minutes, hours,
+          and days, respectively. If the unit is omitted, seconds is
+          assumed. This flag additionally accepts the special value "never" to
+          indicate that the subscription will never expire.""")
 
 
 def AddPublishMessageFlags(parser, add_deprecated=False):
@@ -265,7 +264,7 @@ def AddPublishMessageFlags(parser, add_deprecated=False):
   parser.add_argument(
       '--attribute', type=arg_parsers.ArgDict(max_length=MAX_ATTRIBUTES),
       help='Comma-separated list of attributes. Each ATTRIBUTE has the form '
-           'name=value". You can specify up to {0} attributes.'.format(
+           'name="value". You can specify up to {0} attributes.'.format(
                MAX_ATTRIBUTES))
 
 
