@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2018 Google Inc. All Rights Reserved.
+# Copyright 2018 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -75,6 +75,10 @@ class Question(six.with_metaclass(abc.ABCMeta, object)):
   def question(self):
     return self._question
 
+  @question.setter
+  def question(self, question):
+    self._question = question
+
   @property
   def instruction(self):
     return self._instruction
@@ -83,8 +87,12 @@ class Question(six.with_metaclass(abc.ABCMeta, object)):
   def instruction_on_rejection(self):
     return self._instruction_on_rejection
 
-  @abc.abstractmethod
   def PrintQuestion(self):
+    self._PrintQuestion()
+    log.out.flush()
+
+  @abc.abstractmethod
+  def _PrintQuestion(self):
     pass
 
   def PrintInstruction(self):
@@ -162,7 +170,7 @@ class MultiChoiceQuestion(Question):
       raise QuestionCreationError('Question cannot be created because some '
                                   'required field is missing.')
 
-  def PrintQuestion(self):
+  def _PrintQuestion(self):
     """Prints question and lists all choices."""
     choices_repr = [
         '[{}] {}'.format(index, msg)
@@ -207,7 +215,7 @@ class MultiChoiceQuestion(Question):
 class FreeTextQuestion(Question):
   """Free text question."""
 
-  def PrintQuestion(self):
+  def _PrintQuestion(self):
     question = survey_util.Indent(self._question, 1)
     log.Print(question)
 
