@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2017 Google Inc. All Rights Reserved.
+# Copyright 2017 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -442,7 +442,7 @@ def ChoiceToEnum(choice, enum_type, item_type='choice', valid_choices=None):
   """Converts the typed choice into an apitools Enum value."""
   if choice is None:
     return None
-  name = choice.replace('-', '_').upper()
+  name = ChoiceToEnumName(choice)
   valid_choices = (valid_choices or
                    [EnumNameToChoice(n) for n in enum_type.names()])
   try:
@@ -455,6 +455,11 @@ def ChoiceToEnum(choice, enum_type, item_type='choice', valid_choices=None):
             values=', '.join(c for c in sorted(valid_choices))))
 
 
+def ChoiceToEnumName(choice):
+  """Converts a typeable choice to the string representation of the Enum."""
+  return choice.replace('-', '_').upper()
+
+
 def EnumNameToChoice(name):
   """Converts the name of an Enum value into a typeable choice."""
   return name.replace('_', '-').lower()
