@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2016 Google Inc. All Rights Reserved.
+# Copyright 2016 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -67,7 +67,8 @@ class Submit(base.CreateCommand):
   """
 
   detailed_help = {
-      'DESCRIPTION': """\
+      'DESCRIPTION':
+          """\
           {description}
 
           When the `builds/use_kaniko` property is `True`, builds submitted with
@@ -80,9 +81,8 @@ class Submit(base.CreateCommand):
   }
 
   _machine_type_flag_map = arg_utils.ChoiceEnumMapper(
-      '--machine-type',
-      (cloudbuild_util.GetMessagesModule()
-      ).BuildOptions.MachineTypeValueValuesEnum,
+      '--machine-type', (cloudbuild_util.GetMessagesModule()
+                        ).BuildOptions.MachineTypeValueValuesEnum,
       include_filter=lambda s: str(s) != 'UNSPECIFIED',
       help_str='Machine type used to run the build.')
 
@@ -102,7 +102,8 @@ class Submit(base.CreateCommand):
         help='The location of the source to build. The location can be a '
         'directory on a local disk or a gzipped archive file (.tar.gz) in '
         'Google Cloud Storage. If the source is a local directory, this '
-        'command skips the files specified in the `.gcloudignore` file. If a '
+        'command skips the files specified in the `--ignore-file`. If '
+        '`--ignore-file` is not specified, use`.gcloudignore` file. If a '
         '`.gitignore` file is present in the local source directory, gcloud '
         'will use a Git-compatible `.gcloudignore` file that respects your '
         '.gitignored files. The global `.gitignore` is not respected. For more '
@@ -196,8 +197,7 @@ https://cloud.google.com/cloud-build/docs/api/build-requests#substitutions
         'This has the same effect as setting the builds/kaniko_cache_ttl '
         'property to 0 for this build.  This can be useful in cases where '
         'Dockerfile builds are non-deterministic and a non-deterministic '
-        'result should not be cached.'
-    )
+        'result should not be cached.')
     base.ASYNC_FLAG.AddToParser(parser)
     parser.display_info.AddFormat("""
           table(
@@ -212,6 +212,11 @@ https://cloud.google.com/cloud-build/docs/api/build-requests#substitutions
     # Do not try to create a URI to update the cache.
     parser.display_info.AddCacheUpdater(None)
 
+    parser.add_argument(
+        '--ignore-file',
+        help='Override the `.gcloudignore` file and use the specified file '
+        'instead.')
+
   def Run(self, args):
     """This is what gets called when the user runs this command.
 
@@ -273,9 +278,10 @@ https://cloud.google.com/cloud-build/docs/api/build-requests#substitutions
             steps=[
                 messages.BuildStep(
                     name=properties.VALUES.builds.kaniko_image.Get(),
-                    args=['--destination', args.tag,
-                          '--cache', 'true',
-                          '--cache-ttl', ttl],
+                    args=[
+                        '--destination', args.tag, '--cache', 'true',
+                        '--cache-ttl', ttl
+                    ],
                 ),
             ],
             timeout=timeout_str,
@@ -292,7 +298,10 @@ https://cloud.google.com/cloud-build/docs/api/build-requests#substitutions
             steps=[
                 messages.BuildStep(
                     name='gcr.io/cloud-builders/docker',
-                    args=['build', '--no-cache', '-t', args.tag, '.'],
+                    args=[
+                        'build', '--network', 'cloudbuild', '--no-cache', '-t',
+                        args.tag, '.'
+                    ],
                 ),
             ],
             timeout=timeout_str,
@@ -383,7 +392,8 @@ https://cloud.google.com/cloud-build/docs/api/build-requests#substitutions
           raise c_exceptions.BadFileException(
               'could not find source [{src}]'.format(src=args.source))
         if os.path.isdir(args.source):
-          source_snapshot = snapshot.Snapshot(args.source)
+          source_snapshot = snapshot.Snapshot(args.source,
+                                              ignore_file=args.ignore_file)
           size_str = resource_transform.TransformSize(
               source_snapshot.uncompressed_size)
           log.status.Print(
@@ -391,7 +401,7 @@ https://cloud.google.com/cloud-build/docs/api/build-requests#substitutions
               ' totalling {size} before compression.'.format(
                   num_files=len(source_snapshot.files), size=size_str))
           staged_source_obj = source_snapshot.CopyTarballToGCS(
-              gcs_client, gcs_source_staging)
+              gcs_client, gcs_source_staging, ignore_file=args.ignore_file)
           build_config.source = messages.Source(
               storageSource=messages.StorageSource(
                   bucket=staged_source_obj.bucket,
@@ -410,8 +420,8 @@ https://cloud.google.com/cloud-build/docs/api/build-requests#substitutions
                                bucket=gcs_source_staging.bucket,
                                object=gcs_source_staging.object,
                            ))
-          staged_source_obj = gcs_client.CopyFileToGCS(
-              args.source, gcs_source_staging)
+          staged_source_obj = gcs_client.CopyFileToGCS(args.source,
+                                                       gcs_source_staging)
           build_config.source = messages.Source(
               storageSource=messages.StorageSource(
                   bucket=staged_source_obj.bucket,
@@ -428,8 +438,8 @@ https://cloud.google.com/cloud-build/docs/api/build-requests#substitutions
       gcs_log_dir = resources.REGISTRY.Parse(
           args.gcs_log_dir, collection='storage.objects')
 
-      build_config.logsBucket = (
-          'gs://' + gcs_log_dir.bucket + '/' + gcs_log_dir.object)
+      build_config.logsBucket = ('gs://' + gcs_log_dir.bucket + '/' +
+                                 gcs_log_dir.object)
 
     # Machine type.
     if args.machine_type is not None:
