@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2014 Google Inc. All Rights Reserved.
+# Copyright 2014 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,9 @@
 """Command for adding a backend to a backend service."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 from apitools.base.py import encoding
 
 from googlecloudsdk.api_lib.compute import base_classes
@@ -52,8 +54,7 @@ class AddBackend(base.UpdateCommand):
   def Args(parser):
     flags.GLOBAL_REGIONAL_BACKEND_SERVICE_ARG.AddArgument(parser)
     backend_flags.AddDescription(parser)
-    flags.MULTISCOPE_INSTANCE_GROUP_ARG.AddArgument(
-        parser, operation_type='add to the backend service')
+    flags.AddInstanceGroupAndNetworkEndpointGroupArgs(parser, 'add to')
     backend_flags.AddBalancingMode(parser)
     backend_flags.AddCapacityLimits(parser)
     backend_flags.AddCapacityScalar(parser)
@@ -89,10 +90,16 @@ class AddBackend(base.UpdateCommand):
                 project=backend_service_ref.project))
 
   def _GetGroupRef(self, args, resources, client):
-    return flags.MULTISCOPE_INSTANCE_GROUP_ARG.ResolveAsResource(
-        args,
-        resources,
-        scope_lister=compute_flags.GetDefaultScopeLister(client))
+    if args.instance_group:
+      return flags.MULTISCOPE_INSTANCE_GROUP_ARG.ResolveAsResource(
+          args,
+          resources,
+          scope_lister=compute_flags.GetDefaultScopeLister(client))
+    if args.network_endpoint_group:
+      return flags.NETWORK_ENDPOINT_GROUP_ARG.ResolveAsResource(
+          args,
+          resources,
+          scope_lister=compute_flags.GetDefaultScopeLister(client))
 
   def _CreateBackendMessage(self, messages, group_uri, balancing_mode, args):
     """Create a backend message.
@@ -117,9 +124,11 @@ class AddBackend(base.UpdateCommand):
         group=group_uri,
         maxRate=args.max_rate,
         maxRatePerInstance=args.max_rate_per_instance,
+        maxRatePerEndpoint=args.max_rate_per_endpoint,
         maxUtilization=args.max_utilization,
         maxConnections=args.max_connections,
-        maxConnectionsPerInstance=args.max_connections_per_instance)
+        maxConnectionsPerInstance=args.max_connections_per_instance,
+        maxConnectionsPerEndpoint=args.max_connections_per_endpoint)
 
   def _Modify(self, client, resources, backend_service_ref, args, existing):
     replacement = encoding.CopyProtoMessage(existing)
@@ -182,42 +191,12 @@ class AddBackendBeta(AddBackend):
   backend is a group of tasks that can handle requests sent to a
   backend service. Currently, the group of tasks can be one or
   more Google Compute Engine virtual machine instances grouped
-  together using an instance group.
+  together using an instance group or network endpoint group.
 
-  Traffic is first spread evenly across all virtual machines in
-  the group. When the group is full, traffic is sent to the next
-  nearest group(s) that still have remaining capacity.
-
-  To modify the parameters of a backend after it has been added
-  to the backend service, use
-  `gcloud compute backend-services update-backend` or
-  `gcloud compute backend-services edit`.
-  """
-
-  @staticmethod
-  def Args(parser):
-    flags.GLOBAL_REGIONAL_BACKEND_SERVICE_ARG.AddArgument(parser)
-    backend_flags.AddDescription(parser)
-    flags.MULTISCOPE_INSTANCE_GROUP_ARG.AddArgument(
-        parser, operation_type='add to the backend service')
-    backend_flags.AddBalancingMode(parser)
-    backend_flags.AddCapacityLimits(parser)
-    backend_flags.AddCapacityScalar(parser)
-
-
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
-class AddBackendAlpha(AddBackendBeta):
-  """Add a backend to a backend service.
-
-  *{command}* is used to add a backend to a backend service. A
-  backend is a group of tasks that can handle requests sent to a
-  backend service. Currently, the group of tasks can be one or
-  more Google Compute Engine virtual machine instances grouped
-  together using an instance group.
-
-  Traffic is first spread evenly across all virtual machines in
-  the group. When the group is full, traffic is sent to the next
-  nearest group(s) that still have remaining capacity.
+  Traffic is first spread evenly across all virtual machines or
+  network endpoints in the group. When the group is full, traffic
+  is sent to the next nearest group(s) that still have remaining
+  capacity.
 
   To modify the parameters of a backend after it has been added
   to the backend service, use
@@ -230,28 +209,65 @@ class AddBackendAlpha(AddBackendBeta):
     flags.GLOBAL_REGIONAL_BACKEND_SERVICE_ARG.AddArgument(parser)
     flags.AddInstanceGroupAndNetworkEndpointGroupArgs(parser, 'add to')
     backend_flags.AddDescription(parser)
-    backend_flags.AddBalancingMode(parser, supports_neg=True)
-    backend_flags.AddCapacityLimits(parser, supports_neg=True)
+    backend_flags.AddBalancingMode(parser)
+    backend_flags.AddCapacityLimits(parser)
     backend_flags.AddCapacityScalar(parser)
     backend_flags.AddFailover(parser, default=None)
 
-  def _GetGroupRef(self, args, resources, client):
-    if args.instance_group:
-      return flags.MULTISCOPE_INSTANCE_GROUP_ARG.ResolveAsResource(
-          args,
-          resources,
-          scope_lister=compute_flags.GetDefaultScopeLister(client))
-    if args.network_endpoint_group:
-      return flags.NETWORK_ENDPOINT_GROUP_ARG.ResolveAsResource(
-          args,
-          resources,
-          scope_lister=compute_flags.GetDefaultScopeLister(client))
-
   def _CreateBackendMessage(self, messages, group_uri, balancing_mode, args):
     """Overrides."""
 
-    backend_services_utils.ValidateBalancingModeArgs(
-        messages, args, supports_neg=True)
+    backend_services_utils.ValidateBalancingModeArgs(messages, args)
+    return messages.Backend(
+        balancingMode=balancing_mode,
+        capacityScaler=args.capacity_scaler,
+        description=args.description,
+        group=group_uri,
+        maxRate=args.max_rate,
+        maxRatePerInstance=args.max_rate_per_instance,
+        maxRatePerEndpoint=args.max_rate_per_endpoint,
+        maxUtilization=args.max_utilization,
+        maxConnections=args.max_connections,
+        maxConnectionsPerInstance=args.max_connections_per_instance,
+        maxConnectionsPerEndpoint=args.max_connections_per_endpoint,
+        failover=args.failover)
+
+
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+class AddBackendAlpha(AddBackendBeta):
+  """Add a backend to a backend service.
+
+  *{command}* is used to add a backend to a backend service. A
+  backend is a group of tasks that can handle requests sent to a
+  backend service. Currently, the group of tasks can be one or
+  more Google Compute Engine virtual machine instances grouped
+  together using an instance group or network endpoint group.
+
+  Traffic is first spread evenly across all virtual machines or
+  network endpoints in the group. When the group is full, traffic
+  is sent to the next nearest group(s) that still have remaining
+  capacity.
+
+  To modify the parameters of a backend after it has been added
+  to the backend service, use
+  `gcloud compute backend-services update-backend` or
+  `gcloud compute backend-services edit`.
+  """
+
+  @staticmethod
+  def Args(parser):
+    flags.GLOBAL_REGIONAL_BACKEND_SERVICE_ARG.AddArgument(parser)
+    flags.AddInstanceGroupAndNetworkEndpointGroupArgs(parser, 'add to')
+    backend_flags.AddDescription(parser)
+    backend_flags.AddBalancingMode(parser)
+    backend_flags.AddCapacityLimits(parser)
+    backend_flags.AddCapacityScalar(parser)
+    backend_flags.AddFailover(parser, default=None)
+
+  def _CreateBackendMessage(self, messages, group_uri, balancing_mode, args):
+    """Overrides."""
+
+    backend_services_utils.ValidateBalancingModeArgs(messages, args)
     return messages.Backend(
         balancingMode=balancing_mode,
         capacityScaler=args.capacity_scaler,
