@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2014 Google Inc. All Rights Reserved.
+# Copyright 2014 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -104,7 +104,8 @@ def _SourceArgs(parser, source_snapshot_arg):
 
 def _CommonArgs(parser,
                 source_snapshot_arg,
-                include_physical_block_size_support=False):
+                include_physical_block_size_support=False,
+                vss_erase_enabled=False):
   """Add arguments used for parsing in all command tracks."""
   Create.disks_arg.AddArgument(parser, operation_type='create')
   parser.add_argument(
@@ -162,6 +163,8 @@ def _CommonArgs(parser,
 Physical block size of the persistent disk in bytes.
 Valid values are 4096(default) and 16384.
 """)
+  if vss_erase_enabled:
+    flags.AddEraseVssSignature(parser, resource='a source snapshot')
 
 
 def _AddReplicaZonesArg(parser):
@@ -198,6 +201,7 @@ class Create(base.Command):
     Create.disks_arg = disks_flags.MakeDiskArg(plural=True)
     _CommonArgs(parser, disks_flags.SOURCE_SNAPSHOT_ARG)
     image_utils.AddGuestOsFeaturesArg(parser, base.ReleaseTrack.GA)
+    _AddReplicaZonesArg(parser)
     kms_resource_args.AddKmsKeyResourceArg(
         parser, 'disk', region_fallthrough=True)
 
@@ -217,21 +221,7 @@ class Create(base.Command):
     return []
 
   def ValidateAndParseDiskRefs(self, args, compute_holder):
-    """Validate flags and parse disks references.
-
-    Subclasses may override it to customize parsing.
-
-    Args:
-      args: The argument namespace
-      compute_holder: base_classes.ComputeApiHolder instance
-
-    Returns:
-      List of compute.regionDisks resources.
-    """
-    return Create.disks_arg.ResolveAsResource(
-        args,
-        compute_holder.resources,
-        scope_lister=flags.GetDefaultScopeLister(compute_holder.client))
+    return _ValidateAndParseDiskRefsRegionalReplica(args, compute_holder)
 
   def GetFromImage(self, args):
     return args.image or args.image_family
@@ -331,7 +321,8 @@ class Create(base.Command):
   def Run(self, args):
     return self._Run(args, supports_kms_keys=True)
 
-  def _Run(self, args, supports_kms_keys=False, supports_physical_block=False):
+  def _Run(self, args, supports_kms_keys=False, supports_physical_block=False,
+           support_shared_disk=False, support_vss_erase=False):
     compute_holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
     client = compute_holder.client
 
@@ -423,10 +414,21 @@ class Create(base.Command):
           type=type_uri,
           physicalBlockSizeBytes=physical_block_size_bytes,
           **kwargs)
+      if (support_shared_disk and disk_ref.Collection() == 'compute.regionDisks'
+          and args.IsSpecified('multi_writer')):
+        raise exceptions.InvalidArgumentException('--multi-writer', (
+            '--multi-writer can be used only with --zone flag'))
+
+      if (support_shared_disk and disk_ref.Collection() == 'compute.disks' and
+          args.IsSpecified('multi_writer')):
+        disk.multiWriter = args.multi_writer
 
       if guest_os_feature_messages:
         disk.guestOsFeatures = guest_os_feature_messages
 
+      if support_vss_erase and args.IsSpecified('erase_windows_vss_signature'):
+        disk.eraseWindowsVssSignature = args.erase_windows_vss_signature
+
       disk.licenses = self.ParseLicenses(args)
 
       if disk_ref.Collection() == 'compute.disks':
@@ -469,7 +471,7 @@ class CreateBeta(Create):
 
   @staticmethod
   def Args(parser):
-    Create.disks_arg = disks_flags.MakeDiskArgZonalOrRegional(plural=True)
+    Create.disks_arg = disks_flags.MakeDiskArg(plural=True)
 
     _CommonArgs(
         parser,
@@ -481,9 +483,6 @@ class CreateBeta(Create):
     kms_resource_args.AddKmsKeyResourceArg(
         parser, 'disk', region_fallthrough=True)
 
-  def ValidateAndParseDiskRefs(self, args, compute_holder):
-    return _ValidateAndParseDiskRefsRegionalReplica(args, compute_holder)
-
   def Run(self, args):
     return self._Run(args, supports_kms_keys=True, supports_physical_block=True)
 
@@ -494,23 +493,30 @@ class CreateAlpha(Create):
 
   @staticmethod
   def Args(parser):
-    Create.disks_arg = disks_flags.MakeDiskArgZonalOrRegional(plural=True)
+    Create.disks_arg = disks_flags.MakeDiskArg(plural=True)
 
     _CommonArgs(
         parser,
         disks_flags.SOURCE_SNAPSHOT_ARG,
-        include_physical_block_size_support=True)
+        include_physical_block_size_support=True,
+        vss_erase_enabled=True)
     image_utils.AddGuestOsFeaturesArg(parser, base.ReleaseTrack.ALPHA)
     _AddReplicaZonesArg(parser)
     resource_flags.AddResourcePoliciesArgs(parser, 'added to', 'disk')
     kms_resource_args.AddKmsKeyResourceArg(
         parser, 'disk', region_fallthrough=True)
-
-  def ValidateAndParseDiskRefs(self, args, compute_holder):
-    return _ValidateAndParseDiskRefsRegionalReplica(args, compute_holder)
+    parser.add_argument(
+        '--multi-writer',
+        action='store_true',
+        help=('Create the disk in shared mode so that it can be attached with '
+              'read-write access to multiple VMs. Available only for zonal '
+              'disks. Cannot be used with regional disks. Shared disk is '
+              'exposed only as an NVMe device. Shared PD does not yet support '
+              'resize and snapshot operations.'))
 
   def Run(self, args):
-    return self._Run(args, supports_kms_keys=True, supports_physical_block=True)
+    return self._Run(args, supports_kms_keys=True, supports_physical_block=True,
+                     support_shared_disk=True, support_vss_erase=True)
 
 
 def _ValidateAndParseDiskRefsRegionalReplica(args, compute_holder):
