@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2015 Google Inc. All Rights Reserved.
+# Copyright 2015 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -24,14 +24,42 @@ from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.compute.health_checks import flags
 
 
-def _Run(args, holder, supports_port_specification=False, include_alpha=False):
+def _DetailedHelp():
+  return {
+      'brief':
+          'Create a SSL health check to monitor load balanced instances.',
+      'DESCRIPTION':
+          """\
+          *{command}* is used to create a SSL health check. SSL health checks
+          monitor instances in a load balancer controlled by a target pool. All
+          arguments to the command are optional except for the name of the
+          health check. For more information on load balancing, see
+          [](https://cloud.google.com/compute/docs/load-balancing-and-autoscaling/)
+          """,
+  }
+
+
+def _Args(parser, include_l7_internal_load_balancing=False):
+  """Set up arguments to create an SSL HealthCheck."""
+  parser.display_info.AddFormat(flags.DEFAULT_LIST_FORMAT)
+  flags.HealthCheckArgument(
+      'SSL',
+      include_l7_internal_load_balancing=include_l7_internal_load_balancing
+  ).AddArgument(
+      parser, operation_type='create')
+  health_checks_utils.AddTcpRelatedCreationArgs(parser)
+  health_checks_utils.AddProtocolAgnosticCreationArgs(parser, 'SSL')
+
+
+def _Run(args, holder, include_l7_internal_load_balancing=False):
   """Issues the request necessary for adding the health check."""
   client = holder.client
   messages = client.messages
 
   health_check_ref = flags.HealthCheckArgument(
-      'SSL', include_alpha=include_alpha).ResolveAsResource(
-          args, holder.resources)
+      'SSL',
+      include_l7_internal_load_balancing=include_l7_internal_load_balancing
+  ).ResolveAsResource(args, holder.resources)
   proxy_header = messages.SSLHealthCheck.ProxyHeaderValueValuesEnum(
       args.proxy_header)
   ssl_health_check = messages.SSLHealthCheck(
@@ -41,9 +69,8 @@ def _Run(args, holder, supports_port_specification=False, include_alpha=False):
       portName=args.port_name,
       proxyHeader=proxy_header)
 
-  if supports_port_specification:
-    health_checks_utils.ValidateAndAddPortSpecificationToHealthCheck(
-        args, ssl_health_check)
+  health_checks_utils.ValidateAndAddPortSpecificationToHealthCheck(
+      args, ssl_health_check)
 
   if health_checks_utils.IsRegionalHealthCheckRef(health_check_ref):
     request = messages.ComputeRegionHealthChecksInsertRequest(
@@ -78,73 +105,33 @@ def _Run(args, holder, supports_port_specification=False, include_alpha=False):
 
 @base.ReleaseTracks(base.ReleaseTrack.GA)
 class Create(base.CreateCommand):
-  """Create a SSL health check to monitor load balanced instances."""
+  """Create a SSL health check."""
+
+  _include_l7_internal_load_balancing = False
+  detailed_help = _DetailedHelp()
 
   @classmethod
-  def Args(cls,
-           parser,
-           supports_port_specification=False,
-           supports_use_serving_port=False,
-           regionalized=False):
-    parser.display_info.AddFormat(flags.DEFAULT_LIST_FORMAT)
-    flags.HealthCheckArgument(
-        'SSL', include_alpha=regionalized).AddArgument(
-            parser, operation_type='create')
-    health_checks_utils.AddTcpRelatedCreationArgs(
+  def Args(cls, parser):
+    _Args(
         parser,
-        port_specification=supports_port_specification,
-        use_serving_port=supports_use_serving_port)
-    health_checks_utils.AddProtocolAgnosticCreationArgs(parser, 'SSL')
+        include_l7_internal_load_balancing=cls
+        ._include_l7_internal_load_balancing)
 
   def Run(self, args):
-    """Issues the request necessary for adding the health check."""
     holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
-    return _Run(args, holder)
+    return _Run(
+        args,
+        holder,
+        include_l7_internal_load_balancing=self
+        ._include_l7_internal_load_balancing)
 
 
 @base.ReleaseTracks(base.ReleaseTrack.BETA)
 class CreateBeta(Create):
-  """Create a SSL health check to monitor load balanced instances."""
 
-  @staticmethod
-  def Args(parser,
-           supports_port_specification=False,
-           supports_use_serving_port=True,
-           regionalized=False):
-    Create.Args(
-        parser,
-        supports_port_specification=supports_port_specification,
-        supports_use_serving_port=supports_use_serving_port,
-        regionalized=regionalized)
-
-  def Run(self, args):
-    """Issues the request necessary for adding the health check."""
-    holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
-    return _Run(args, holder, supports_port_specification=True)
+  _include_l7_internal_load_balancing = True
 
 
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
 class CreateAlpha(CreateBeta):
-  """Create a SSL health check to monitor load balanced instances."""
-
-  @staticmethod
-  def Args(parser):
-    CreateBeta.Args(parser, supports_port_specification=True, regionalized=True)
-
-  def Run(self, args):
-    """Issues the request necessary for adding the health check."""
-    holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
-    return _Run(
-        args, holder, supports_port_specification=True, include_alpha=True)
-
-
-Create.detailed_help = {
-    'brief': 'Create a SSL health check to monitor load balanced instances.',
-    'DESCRIPTION': """\
-        *{command}* is used to create a SSL health check. SSL health checks
-        monitor instances in a load balancer controlled by a target pool. All
-        arguments to the command are optional except for the name of the health
-        check. For more information on load balancing, see
-        [](https://cloud.google.com/compute/docs/load-balancing-and-autoscaling/)
-        """,
-}
+  pass
