@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2019 Google Inc. All Rights Reserved.
+# Copyright 2019 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -23,12 +23,13 @@ import re
 from googlecloudsdk.api_lib.compute import base_classes
 from googlecloudsdk.api_lib.compute import daisy_utils
 from googlecloudsdk.api_lib.compute import instance_utils
+from googlecloudsdk.api_lib.storage import storage_util
 from googlecloudsdk.calliope import base
 from googlecloudsdk.calliope import exceptions
 from googlecloudsdk.command_lib.compute import completers
 from googlecloudsdk.command_lib.compute.images import os_choices
-from googlecloudsdk.command_lib.compute.instances \
-  import flags as instances_flags
+from googlecloudsdk.command_lib.compute.instances import flags as instances_flags
+from googlecloudsdk.command_lib.compute.sole_tenancy import flags as sole_tenancy_flags
 from googlecloudsdk.command_lib.util.args import labels_util
 from googlecloudsdk.core import log
 from googlecloudsdk.core import properties
@@ -77,41 +78,41 @@ class Import(base.CreateCommand):
         '--guest-environment',
         action='store_true',
         default=True,
-        help='Google Guest Environment will not be installed on the instance.')
+        help='Google Guest Environment will be installed on the instance.')
 
     parser.display_info.AddCacheUpdater(completers.InstancesCompleter)
 
-  def _ValidateInstanceNames(self, args):
-    """Raise an exception if any of the requested instance names are invalid."""
-    instance_name_pattern = re.compile('^[a-z]([-a-z0-9]{0,61}[a-z0-9])?$')
-    for instance_name in args.instance_names:
-      if not instance_name_pattern.match(instance_name):
-        raise exceptions.InvalidArgumentException(
-            'INSTANCE_NAMES',
-            'Name must start with a lowercase letter followed by up to '
-            '63 lowercase letters, numbers, or hyphens, and cannot end '
-            'with a hyphen.')
+    sole_tenancy_flags.AddNodeAffinityFlagToParser(parser)
 
-  def _CheckForExistingInstances(self, instance_names, client):
+  def _ValidateInstanceName(self, args):
+    """Raise an exception if requested instance name is invalid."""
+    instance_name_pattern = re.compile('^[a-z]([-a-z0-9]{0,61}[a-z0-9])?$')
+    if not instance_name_pattern.match(args.instance_name):
+      raise exceptions.InvalidArgumentException(
+          'INSTANCE_NAME',
+          'Name must start with a lowercase letter followed by up to '
+          '63 lowercase letters, numbers, or hyphens, and cannot end '
+          'with a hyphen.')
+
+  def _CheckForExistingInstances(self, instance_name, client):
     """Check that the destination instances do not already exist."""
 
-    for instance_name in instance_names:
-      request = (client.apitools_client.instances, 'Get',
-                 client.messages.ComputeInstancesGetRequest(
-                     instance=instance_name,
-                     project=properties.VALUES.core.project.GetOrFail(),
-                     zone=properties.VALUES.compute.zone.GetOrFail()))
-      errors = []
-      client.MakeRequests([request], errors_to_collect=errors)
-      if not errors:
-        message = 'The instance [{0}] already exists.'.format(instance_name)
-        raise exceptions.InvalidArgumentException('INSTANCE_NAMES', message)
+    request = (client.apitools_client.instances, 'Get',
+               client.messages.ComputeInstancesGetRequest(
+                   instance=instance_name,
+                   project=properties.VALUES.core.project.GetOrFail(),
+                   zone=properties.VALUES.compute.zone.GetOrFail()))
+    errors = []
+    client.MakeRequests([request], errors_to_collect=errors)
+    if not errors:
+      message = 'The instance [{0}] already exists.'.format(instance_name)
+      raise exceptions.InvalidArgumentException('INSTANCE_NAME', message)
 
   def Run(self, args):
     compute_holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
 
-    self._ValidateInstanceNames(args)
-    self._CheckForExistingInstances(args.instance_names, compute_holder.client)
+    self._ValidateInstanceName(args)
+    self._CheckForExistingInstances(args.instance_name, compute_holder.client)
 
     instances_flags.ValidateNicFlags(args)
     instances_flags.ValidateNetworkTierArgs(args)
@@ -119,16 +120,27 @@ class Import(base.CreateCommand):
     log.warning('Importing OVF. This may take 40 minutes for smaller OVFs '
                 'and up to a couple of hours for larger OVFs.')
 
-    machine_type = instance_utils.InterpretMachineType(
-        machine_type=args.machine_type,
-        custom_cpu=args.custom_cpu,
-        custom_memory=args.custom_memory,
-        ext=getattr(args, 'custom_extensions', None))
+    machine_type = None
+    if args.machine_type or args.custom_cpu or args.custom_memory:
+      machine_type = instance_utils.InterpretMachineType(
+          machine_type=args.machine_type,
+          custom_cpu=args.custom_cpu,
+          custom_memory=args.custom_memory,
+          ext=getattr(args, 'custom_extensions', None),
+          vm_gen=getattr(args, 'custom_vm_gen', None))
+
+    try:
+      source_uri = daisy_utils.MakeGcsObjectOrPathUri(args.source_uri)
+    except storage_util.InvalidObjectNameError:
+      raise exceptions.InvalidArgumentException(
+          'source-uri',
+          'must be a path to an object or a directory in Google Cloud Storage')
 
     return daisy_utils.RunOVFImportBuild(
         args=args,
-        instance_names=args.instance_names,
-        source_uri=daisy_utils.MakeGcsUri(args.source_uri),
+        compute_client=compute_holder.client,
+        instance_name=args.instance_name,
+        source_uri=source_uri,
         no_guest_environment=not args.guest_environment,
         can_ip_forward=args.can_ip_forward,
         deletion_protection=args.deletion_protection,
@@ -144,7 +156,8 @@ class Import(base.CreateCommand):
         tags=args.tags,
         zone=properties.VALUES.compute.zone.Get(),
         project=args.project,
-        output_filter=_OUTPUT_FILTER)
+        output_filter=_OUTPUT_FILTER,
+    )
 
 
 Import.detailed_help = {
