@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2019 Google Inc. All Rights Reserved.
+# Copyright 2019 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -35,7 +35,7 @@ from googlecloudsdk.core.resource import resource_filter
 from googlecloudsdk.core.resource import resource_projector
 
 
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+@base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.ALPHA)
 class ListInstances(base.ListCommand):
   r"""List instances with specific OS inventory data values.
 
@@ -73,7 +73,7 @@ class ListInstances(base.ListCommand):
   than or equal to 235.0.0-0 available through apt, run:
 
         $ {command} --inventory-filter="\
-        PackageUpdates.apt[].google-cloud-sdk.Version>=235.0.0-0"
+        PackageUpdates.apt[].['google-cloud-sdk'].Version>=235.0.0-0"
 
   To list all instances missing the Stackdriver monitoring package
   stackdriver-agent, run:
@@ -97,7 +97,6 @@ class ListInstances(base.ListCommand):
 
   _GUEST_ATTRIBUTES_PACKAGE_FIELD_KEYS = ('InstalledPackages', 'PackageUpdates')
 
-  # See go/osconfig-agent.
   _SPECIAL_PACKAGE_MANAGERS = ('wua', 'qfe')
   _REGULAR_PACKAGE_MANAGERS = ('deb', 'googet', 'rpm', 'gem', 'pip')
 
@@ -238,8 +237,9 @@ class ListInstances(base.ListCommand):
             'package version must be specified together with a package name. '
             'e.g. --package-name google-cloud-sdk --package-version 235.0.0-0')
       else:
+        package_name = '[\'{}\']'.format(args.package_name)
         _AppendQuery(' OR '.join([
-            '({})'.format(prefix + args.package_name + '.Version=' +
+            '({})'.format(prefix + package_name + '.Version=' +
                           args.package_version)
             for prefix in installed_packages_query_prefixes
         ]))
