@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2018 Google Inc. All Rights Reserved.
+# Copyright 2018 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """Delete network endpoint groups command."""
+
 from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
@@ -26,7 +27,14 @@ from googlecloudsdk.core.console import console_io
 
 
 class Delete(base.DeleteCommand):
-  """Deletes a Google Compute Engine network endpoint group."""
+  r"""Deletes a Google Compute Engine network endpoint group.
+
+  ## EXAMPLES
+
+  To delete a network endpoint group:
+
+    $ {command} my-neg --zone=us-central1-a
+  """
 
   @staticmethod
   def Args(parser):
