@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2014 Google Inc. All Rights Reserved.
+# Copyright 2014 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -25,7 +25,7 @@ class Networks(base.Group):
   """List, create, and delete Google Compute Engine networks."""
 
 
-Networks.category = base.COMPUTE_NETWORKING_CATEGORY
+Networks.category = base.NETWORKING_CATEGORY
 
 Networks.detailed_help = {
     'brief': 'List, create, and delete Google Compute Engine networks',
