@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2014 Google Inc. All Rights Reserved.
+# Copyright 2014 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -30,11 +30,11 @@ from googlecloudsdk.calliope import arg_parsers
 from googlecloudsdk.calliope import base
 from googlecloudsdk.calliope import exceptions
 from googlecloudsdk.command_lib.container import constants
+from googlecloudsdk.command_lib.container import container_command_util as cmd_util
 from googlecloudsdk.command_lib.container import flags
 from googlecloudsdk.command_lib.container import messages
 from googlecloudsdk.command_lib.kms import resource_args as kms_resource_args
 from googlecloudsdk.core import log
-from googlecloudsdk.core import properties
 from googlecloudsdk.core.console import console_io
 
 
@@ -204,6 +204,13 @@ def ParseCreateOptionsBase(args):
                 'certificate issued. You can manually enable (or disable) the '
                 'issuance of the client certificate using the '
                 '`--[no-]issue-client-certificate` flag.')
+  if args.IsSpecified('addons') and api_adapter.DASHBOARD in args.addons:
+    log.warning(
+        'The `KubernetesDashboard` addon is deprecated, and will be removed as '
+        'an option for new clusters starting in 1.15. It is recommended to use '
+        'the Cloud Console to manage and monitor your Kubernetes clusters, '
+        'workloads and applications. See: '
+        'https://cloud.google.com/kubernetes-engine/docs/concepts/dashboards')
 
   flags.MungeBasicAuthFlags(args)
 
@@ -213,19 +220,7 @@ def ParseCreateOptionsBase(args):
                 '`--enable-basic-auth` or `--username` is not, our API will '
                 'treat that as `--no-enable-basic-auth`.')
 
-  if (args.IsSpecified('enable_cloud_endpoints') and
-      properties.VALUES.container.new_scopes_behavior.GetBool()):
-    raise util.Error('Flag --[no-]enable-cloud-endpoints is not allowed if '
-                     'property container/ new_scopes_behavior is set to true.')
-  if args.IsSpecified('enable_autorepair'):
-    enable_autorepair = args.enable_autorepair
-  else:
-    # Node pools using COS support auto repairs, enable it for them by default.
-    # Other node pools using (Ubuntu, custom images) don't support node auto
-    # repairs, attempting to enable autorepair for them will result in API call
-    # failing so don't do it.
-    enable_autorepair = ((args.image_type or '').lower() in ['', 'cos'])
-  flags.WarnForUnspecifiedIpAllocationPolicy(args)
+  enable_autorepair = cmd_util.GetAutoRepair(args)
   flags.WarnForNodeModification(args, enable_autorepair)
   metadata = metadata_utils.ConstructMetadataDict(args.metadata,
                                                   args.metadata_from_file)
@@ -241,8 +236,8 @@ def ParseCreateOptionsBase(args):
       disk_type=args.disk_type,
       enable_autorepair=enable_autorepair,
       enable_autoscaling=args.enable_autoscaling,
-      enable_autoupgrade=args.enable_autoupgrade,
-      enable_cloud_endpoints=args.enable_cloud_endpoints,
+      enable_autoupgrade=cmd_util.GetAutoUpgrade(args),
+      enable_stackdriver_kubernetes=args.enable_stackdriver_kubernetes,
       enable_cloud_logging=args.enable_cloud_logging,
       enable_cloud_monitoring=args.enable_cloud_monitoring,
       enable_ip_alias=args.enable_ip_alias,
@@ -284,7 +279,13 @@ def ParseCreateOptionsBase(args):
       user=args.username,
       metadata=metadata,
       default_max_pods_per_node=args.default_max_pods_per_node,
-      max_pods_per_node=args.max_pods_per_node)
+      max_pods_per_node=args.max_pods_per_node,
+      enable_tpu=args.enable_tpu,
+      tpu_ipv4_cidr=args.tpu_ipv4_cidr,
+      resource_usage_bigquery_dataset=args.resource_usage_bigquery_dataset,
+      enable_network_egress_metering=args.enable_network_egress_metering,
+      enable_resource_consumption_metering=\
+          args.enable_resource_consumption_metering)
 
 
 @base.ReleaseTracks(base.ReleaseTrack.GA)
@@ -301,6 +302,7 @@ class Create(base.CreateCommand):
     flags.AddMaxPodsPerNodeFlag(parser)
     flags.AddEnableAutoRepairFlag(parser, for_create=True)
     flags.AddEnableKubernetesAlphaFlag(parser)
+    flags.AddEnableStackdriverKubernetesFlag(parser)
     flags.AddEnableLegacyAuthorizationFlag(parser)
     flags.AddIPAliasFlags(parser)
     flags.AddLabelsFlag(parser)
@@ -311,12 +313,14 @@ class Create(base.CreateCommand):
     flags.AddNetworkPolicyFlags(parser)
     flags.AddNodeTaintsFlag(parser)
     flags.AddPreemptibleFlag(parser)
-    flags.AddDeprecatedClusterNodeIdentityFlags(parser)
+    flags.AddClusterNodeIdentityFlags(parser)
     flags.AddPrivateClusterFlags(
         parser, with_deprecated=False, with_alpha=False)
     flags.AddClusterVersionFlag(parser)
     flags.AddNodeVersionFlag(parser)
     flags.AddEnableAutoUpgradeFlag(parser)
+    flags.AddTpuFlags(parser, hidden=False)
+    flags.AddResourceUsageExportFlags(parser)
 
   def ParseCreateOptions(self, args):
     flags.WarnGAForFutureAutoUpgradeChange()
@@ -367,6 +371,19 @@ class Create(base.CreateCommand):
                   'node pool, run `clusters create` with the flag '
                   '`--metadata disable-legacy-endpoints=true`.')
 
+    if options.enable_ip_alias:
+      log.warning(
+          'The Pod address range limits the maximum size of the cluster. '
+          'Please refer to https://cloud.google.com/kubernetes-engine/docs/how-to/flexible-pod-cidr to learn how to optimize IP address allocation.'
+      )
+    else:
+      max_node_number = util.CalculateMaxNodeNumberByPodRange(
+          options.cluster_ipv4_cidr)
+      if max_node_number > 0:
+        log.warning(
+            'Your Pod address range (`--cluster-ipv4-cidr`) can accommodate at most %d node(s). '
+            % max_node_number)
+
     if options.enable_kubernetes_alpha:
       console_io.PromptContinue(
           message=constants.KUBERNETES_ALPHA_PROMPT,
@@ -450,9 +467,10 @@ class CreateBeta(Create):
     flags.AddAutoprovisioningFlags(parser)
     flags.AddVerticalPodAutoscalingFlag(parser)
     flags.AddResourceUsageExportFlags(parser)
-    flags.AddAuthenticatorSecurityGroupFlags(parser, hidden=True)
+    flags.AddAuthenticatorSecurityGroupFlags(parser)
+    flags.AddEnableIntraNodeVisibilityFlag(parser)
     flags.AddWorkloadIdentityFlags(parser)
-    flags.AddEnableShieldedContainersFlags(parser)
+    flags.AddEnableShieldedNodesFlags(parser)
     flags.AddClusterVersionFlag(parser)
     flags.AddNodeVersionFlag(parser)
     flags.AddEnableAutoUpgradeFlag(parser, default=True)
@@ -467,9 +485,12 @@ class CreateBeta(Create):
 
   def ParseCreateOptions(self, args):
     ops = ParseCreateOptionsBase(args)
-    flags.WarnForAutoUpgrade(args)
+    flags.WarnForNodeVersionAutoUpgrade(args)
     ops.enable_autoprovisioning = args.enable_autoprovisioning
     ops.autoprovisioning_config_file = args.autoprovisioning_config_file
+    ops.autoprovisioning_service_account = args.autoprovisioning_service_account
+    ops.autoprovisioning_scopes = args.autoprovisioning_scopes
+    ops.autoprovisioning_locations = args.autoprovisioning_locations
     ops.min_cpu = args.min_cpu
     ops.max_cpu = args.max_cpu
     ops.min_memory = args.min_memory
@@ -480,19 +501,15 @@ class CreateBeta(Create):
     ops.workload_metadata_from_node = args.workload_metadata_from_node
     ops.enable_pod_security_policy = args.enable_pod_security_policy
     ops.allow_route_overlap = args.allow_route_overlap
-    ops.new_scopes_behavior = True
     ops.private_cluster = args.private_cluster
     ops.enable_stackdriver_kubernetes = args.enable_stackdriver_kubernetes
     ops.enable_binauthz = args.enable_binauthz
-    ops.enable_tpu = args.enable_tpu
-    ops.tpu_ipv4_cidr = args.tpu_ipv4_cidr
     ops.istio_config = args.istio_config
     ops.enable_vertical_pod_autoscaling = args.enable_vertical_pod_autoscaling
-    ops.resource_usage_bigquery_dataset = args.resource_usage_bigquery_dataset
-    ops.enable_network_egress_metering = args.enable_network_egress_metering
+    ops.enable_intra_node_visibility = args.enable_intra_node_visibility
     ops.security_group = args.security_group
     ops.identity_namespace = args.identity_namespace
-    ops.enable_shielded_containers = args.enable_shielded_containers
+    ops.enable_shielded_nodes = args.enable_shielded_nodes
     flags.ValidateIstioConfigCreateArgs(args.istio_config, args.addons)
     kms_ref = args.CONCEPTS.kms_key.Parse()
     if kms_ref:
@@ -553,7 +570,9 @@ class CreateAlpha(Create):
     flags.AddSecurityProfileForCreateFlags(parser)
     flags.AddInitialNodePoolNameArg(parser, hidden=False)
     flags.AddEnablePrivateIpv6AccessFlag(parser, hidden=True)
-    flags.AddEnableShieldedContainersFlags(parser)
+    flags.AddEnableIntraNodeVisibilityFlag(parser)
+    flags.AddEnableShieldedNodesFlags(parser)
+    flags.AddDisableDefaultSnatFlag(parser, for_cluster_create=True)
 
     versioning_groups = parser.add_mutually_exclusive_group("""\
 `--release-channel` cannot be specified if `--cluster-version` or
@@ -574,10 +593,14 @@ class CreateAlpha(Create):
     }
     kms_resource_args.AddKmsKeyResourceArg(
         parser, 'cluster', flag_overrides=kms_flag_overrides)
+    flags.AddSurgeUpgradeFlag(parser)
+    flags.AddMaxUnavailableUpgradeFlag(parser)
+    flags.AddLinuxSysctlFlags(parser)
+    flags.AddShieldedInstanceFlags(parser)
 
   def ParseCreateOptions(self, args):
     ops = ParseCreateOptionsBase(args)
-    flags.WarnForAutoUpgrade(args)
+    flags.WarnForNodeVersionAutoUpgrade(args)
     ops.enable_autoprovisioning = args.enable_autoprovisioning
     ops.autoprovisioning_config_file = args.autoprovisioning_config_file
     ops.min_cpu = args.min_cpu
@@ -596,16 +619,12 @@ class CreateAlpha(Create):
     ops.enable_private_nodes = args.enable_private_nodes
     ops.enable_private_endpoint = args.enable_private_endpoint
     ops.master_ipv4_cidr = args.master_ipv4_cidr
-    ops.new_scopes_behavior = True
-    ops.enable_tpu = args.enable_tpu
-    ops.tpu_ipv4_cidr = args.tpu_ipv4_cidr
     ops.enable_tpu_service_networking = args.enable_tpu_service_networking
     ops.istio_config = args.istio_config
     ops.enable_stackdriver_kubernetes = args.enable_stackdriver_kubernetes
     ops.enable_managed_pod_identity = args.enable_managed_pod_identity
     ops.identity_namespace = args.identity_namespace
     ops.federating_service_account = args.federating_service_account
-    ops.resource_usage_bigquery_dataset = args.resource_usage_bigquery_dataset
     ops.security_group = args.security_group
     flags.ValidateIstioConfigCreateArgs(args.istio_config, args.addons)
     ops.enable_vertical_pod_autoscaling = args.enable_vertical_pod_autoscaling
@@ -613,10 +632,15 @@ class CreateAlpha(Create):
     ops.security_profile_runtime_rules = args.security_profile_runtime_rules
     ops.node_pool_name = args.node_pool_name
     ops.enable_network_egress_metering = args.enable_network_egress_metering
+    ops.enable_resource_consumption_metering = args.enable_resource_consumption_metering
     ops.enable_private_ipv6_access = args.enable_private_ipv6_access
+    ops.enable_intra_node_visibility = args.enable_intra_node_visibility
     ops.enable_peering_route_sharing = args.enable_peering_route_sharing
-    ops.enable_shielded_containers = args.enable_shielded_containers
+    ops.enable_shielded_nodes = args.enable_shielded_nodes
     ops.release_channel = args.release_channel
+    ops.autoprovisioning_service_account = args.autoprovisioning_service_account
+    ops.autoprovisioning_scopes = args.autoprovisioning_scopes
+    ops.autoprovisioning_locations = args.autoprovisioning_locations
     kms_ref = args.CONCEPTS.kms_key.Parse()
     if kms_ref:
       ops.database_encryption = kms_ref.RelativeName()
@@ -629,4 +653,12 @@ class CreateAlpha(Create):
         if getattr(args, keyword.replace('-', '_'), None):
           raise exceptions.InvalidArgumentException('--database-encryption-key',
                                                     'not fully specified.')
+    ops.max_surge_upgrade = args.max_surge_upgrade
+    ops.max_unavailable_upgrade = args.max_unavailable_upgrade
+    ops.linux_sysctls = args.linux_sysctls
+    ops.disable_default_snat = args.disable_default_snat
+
+    ops.shielded_secure_boot = args.shielded_secure_boot
+    ops.shielded_integrity_monitoring = args.shielded_integrity_monitoring
+
     return ops
