@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2015 Google Inc. All Rights Reserved.
+# Copyright 2015 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -79,6 +79,7 @@ def _AddMutuallyExclusiveArgs(mutex_group, release_track):
                 api_adapter.DASHBOARD: _ParseAddonDisabled,
                 api_adapter.NETWORK_POLICY: _ParseAddonDisabled,
                 api_adapter.ISTIO: _ParseAddonDisabled,
+                api_adapter.CLOUDRUN: _ParseAddonDisabled,
             }),
         dest='disable_addons',
         metavar='ADDON=ENABLED|DISABLED',
@@ -87,12 +88,14 @@ def _AddMutuallyExclusiveArgs(mutex_group, release_track):
 {ingress}=ENABLED|DISABLED
 {dashboard}=ENABLED|DISABLED
 {istio}=ENABLED|DISABLED
-{network_policy}=ENABLED|DISABLED""".format(
+{network_policy}=ENABLED|DISABLED
+{cloudrun}=ENABLED|DISABLED""".format(
     hpa=api_adapter.HPA,
     ingress=api_adapter.INGRESS,
     dashboard=api_adapter.DASHBOARD,
     network_policy=api_adapter.NETWORK_POLICY,
     istio=api_adapter.ISTIO,
+    cloudrun=api_adapter.CLOUDRUN,
     ))
 
   else:
@@ -193,12 +196,22 @@ class Update(base.UpdateCommand):
     flags.AddUpdateLabelsFlag(group)
     flags.AddRemoveLabelsFlag(group)
     flags.AddNetworkPolicyFlags(group)
-    flags.AddLoggingServiceFlag(group, enable_kubernetes=False)
-    flags.AddMonitoringServiceFlag(group, enable_kubernetes=False)
+    group_logging_monitoring = group.add_group()
+    flags.AddLoggingServiceFlag(group_logging_monitoring)
+    flags.AddMonitoringServiceFlag(group_logging_monitoring)
+    flags.AddEnableStackdriverKubernetesFlag(group)
     flags.AddMaintenanceWindowFlag(group, add_unset_text=True)
+    flags.AddResourceUsageExportFlags(group, is_update=True)
 
   def ParseUpdateOptions(self, args, locations):
-    return container_command_util.ParseUpdateOptionsBase(args, locations)
+    opts = container_command_util.ParseUpdateOptionsBase(args, locations)
+    opts.resource_usage_bigquery_dataset = args.resource_usage_bigquery_dataset
+    opts.clear_resource_usage_bigquery_dataset = \
+        args.clear_resource_usage_bigquery_dataset
+    opts.enable_network_egress_metering = args.enable_network_egress_metering
+    opts.enable_resource_consumption_metering = \
+        args.enable_resource_consumption_metering
+    return opts
 
   def Run(self, args):
     """This is what gets called when the user runs this command.
@@ -409,10 +422,9 @@ class UpdateBeta(Update):
     _AddAdditionalZonesArg(group_locations, deprecated=True)
     flags.AddNodeLocationsFlag(group_locations)
     group_logging_monitoring = group.add_group()
-    flags.AddLoggingServiceFlag(
-        group_logging_monitoring, enable_kubernetes=True)
-    flags.AddMonitoringServiceFlag(
-        group_logging_monitoring, enable_kubernetes=True)
+    flags.AddLoggingServiceFlag(group_logging_monitoring)
+    flags.AddMonitoringServiceFlag(group_logging_monitoring)
+    flags.AddEnableStackdriverKubernetesFlag(group)
     flags.AddMasterAuthorizedNetworksFlags(
         parser, enable_group_for_update=group)
     flags.AddEnableLegacyAuthorizationFlag(group)
@@ -428,8 +440,12 @@ class UpdateBeta(Update):
     flags.AddEnableBinAuthzFlag(group)
     flags.AddAutoprovisioningFlags(group)
     flags.AddVerticalPodAutoscalingFlag(group)
-    flags.AddResourceUsageExportFlags(group, add_clear_flag=True)
+    flags.AddResourceUsageExportFlags(group, is_update=True)
     flags.AddIstioConfigFlag(parser)
+    flags.AddEnableIntraNodeVisibilityFlag(group)
+    flags.AddWorkloadIdentityFlags(group)
+    flags.AddWorkloadIdentityUpdateFlags(group)
+    flags.AddEnableShieldedNodesFlags(group)
 
   def ParseUpdateOptions(self, args, locations):
     opts = container_command_util.ParseUpdateOptionsBase(args, locations)
@@ -437,6 +453,9 @@ class UpdateBeta(Update):
     opts.enable_binauthz = args.enable_binauthz
     opts.enable_autoprovisioning = args.enable_autoprovisioning
     opts.autoprovisioning_config_file = args.autoprovisioning_config_file
+    opts.autoprovisioning_service_account = args.autoprovisioning_service_account
+    opts.autoprovisioning_scopes = args.autoprovisioning_scopes
+    opts.autoprovisioning_locations = args.autoprovisioning_locations
     opts.min_cpu = args.min_cpu
     opts.max_cpu = args.max_cpu
     opts.min_memory = args.min_memory
@@ -446,10 +465,19 @@ class UpdateBeta(Update):
     opts.enable_vertical_pod_autoscaling = args.enable_vertical_pod_autoscaling
     opts.istio_config = args.istio_config
     opts.resource_usage_bigquery_dataset = args.resource_usage_bigquery_dataset
+    opts.enable_intra_node_visibility = args.enable_intra_node_visibility
     opts.clear_resource_usage_bigquery_dataset = \
         args.clear_resource_usage_bigquery_dataset
     opts.enable_network_egress_metering = args.enable_network_egress_metering
+    opts.enable_resource_consumption_metering = args.enable_resource_consumption_metering
     flags.ValidateIstioConfigUpdateArgs(args.istio_config, args.disable_addons)
+    opts.enable_stackdriver_kubernetes = args.enable_stackdriver_kubernetes
+
+    # Top-level update options are automatically forced to be
+    # mutually-exclusive, so we don't need special handling for these two.
+    opts.identity_namespace = args.identity_namespace
+    opts.disable_workload_identity = args.disable_workload_identity
+    opts.enable_shielded_nodes = args.enable_shielded_nodes
 
     return opts
 
@@ -468,10 +496,9 @@ class UpdateAlpha(Update):
     _AddAdditionalZonesArg(group_locations, deprecated=True)
     flags.AddNodeLocationsFlag(group_locations)
     group_logging_monitoring = group.add_group()
-    flags.AddLoggingServiceFlag(
-        group_logging_monitoring, enable_kubernetes=True)
-    flags.AddMonitoringServiceFlag(
-        group_logging_monitoring, enable_kubernetes=True)
+    flags.AddLoggingServiceFlag(group_logging_monitoring)
+    flags.AddMonitoringServiceFlag(group_logging_monitoring)
+    flags.AddEnableStackdriverKubernetesFlag(group)
     flags.AddMasterAuthorizedNetworksFlags(
         parser, enable_group_for_update=group)
     flags.AddEnableLegacyAuthorizationFlag(group)
@@ -487,16 +514,24 @@ class UpdateAlpha(Update):
     flags.AddMaintenanceWindowFlag(group, add_unset_text=True)
     flags.AddPodSecurityPolicyFlag(group)
     flags.AddEnableBinAuthzFlag(group)
-    flags.AddResourceUsageExportFlags(group, add_clear_flag=True)
+    flags.AddResourceUsageExportFlags(group, is_update=True)
     flags.AddVerticalPodAutoscalingFlag(group)
     flags.AddSecurityProfileForUpdateFlag(group)
     flags.AddIstioConfigFlag(parser)
+    flags.AddEnableIntraNodeVisibilityFlag(group)
     flags.AddPeeringRouteSharingFlag(group)
+    flags.AddWorkloadIdentityFlags(group)
+    flags.AddWorkloadIdentityUpdateFlags(group)
+    flags.AddEnableShieldedNodesFlags(group)
+    flags.AddDisableDefaultSnatFlag(group, for_cluster_create=False)
 
   def ParseUpdateOptions(self, args, locations):
     opts = container_command_util.ParseUpdateOptionsBase(args, locations)
     opts.enable_autoprovisioning = args.enable_autoprovisioning
     opts.autoprovisioning_config_file = args.autoprovisioning_config_file
+    opts.autoprovisioning_service_account = args.autoprovisioning_service_account
+    opts.autoprovisioning_scopes = args.autoprovisioning_scopes
+    opts.autoprovisioning_locations = args.autoprovisioning_locations
     opts.min_cpu = args.min_cpu
     opts.max_cpu = args.max_cpu
     opts.min_memory = args.min_memory
@@ -512,8 +547,18 @@ class UpdateAlpha(Update):
     opts.enable_vertical_pod_autoscaling = args.enable_vertical_pod_autoscaling
     opts.security_profile = args.security_profile
     opts.istio_config = args.istio_config
+    opts.enable_intra_node_visibility = args.enable_intra_node_visibility
     opts.enable_network_egress_metering = args.enable_network_egress_metering
+    opts.enable_resource_consumption_metering = args.enable_resource_consumption_metering
     flags.ValidateIstioConfigUpdateArgs(args.istio_config, args.disable_addons)
     opts.enable_peering_route_sharing = args.enable_peering_route_sharing
+    opts.enable_stackdriver_kubernetes = args.enable_stackdriver_kubernetes
+
+    # Top-level update options are automatically forced to be
+    # mutually-exclusive, so we don't need special handling for these two.
+    opts.identity_namespace = args.identity_namespace
+    opts.disable_workload_identity = args.disable_workload_identity
+    opts.enable_shielded_nodes = args.enable_shielded_nodes
+    opts.disable_default_snat = args.disable_default_snat
 
     return opts
