@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2016 Google Inc. All Rights Reserved.
+# Copyright 2016 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -101,10 +101,6 @@ class Update(base.UpdateCommand):
           messages.AutoUpdateUpgradeRepairMessage(options.enable_autorepair,
                                                   'autorepair'))
 
-    if options.enable_autoupgrade is not None:
-      log.status.Print(
-          messages.AutoUpdateUpgradeRepairMessage(options.enable_autoupgrade,
-                                                  'autoupgrade'))
     try:
       operation_ref = adapter.UpdateNodePool(pool_ref, options)
 
@@ -128,12 +124,18 @@ class UpdateBeta(Update):
   def Args(parser):
     _Args(parser)
     group = parser.add_mutually_exclusive_group(required=True)
+
     node_management_group = group.add_argument_group('Node management')
     flags.AddEnableAutoRepairFlag(node_management_group, for_node_pool=True)
     flags.AddEnableAutoUpgradeFlag(node_management_group, for_node_pool=True)
+
     autoscaling_group = flags.AddClusterAutoscalingFlags(group, hidden=False)
     flags.AddNodePoolAutoprovisioningFlag(autoscaling_group, hidden=True)
 
+    flags.AddWorkloadMetadataFromNodeFlag(group)
+
+    flags.AddNodePoolLocationsFlag(group)
+
   def ParseUpdateNodePoolOptions(self, args):
     ops = api_adapter.UpdateNodePoolOptions(
         enable_autorepair=args.enable_autorepair,
@@ -141,7 +143,9 @@ class UpdateBeta(Update):
         enable_autoscaling=args.enable_autoscaling,
         max_nodes=args.max_nodes,
         min_nodes=args.min_nodes,
-        enable_autoprovisioning=args.enable_autoprovisioning)
+        enable_autoprovisioning=args.enable_autoprovisioning,
+        workload_metadata_from_node=args.workload_metadata_from_node,
+        node_locations=args.node_locations)
     return ops
 
 
@@ -153,12 +157,18 @@ class UpdateAlpha(Update):
   def Args(parser):
     _Args(parser)
     group = parser.add_mutually_exclusive_group(required=True)
+
     node_management_group = group.add_argument_group('Node management')
     flags.AddEnableAutoRepairFlag(node_management_group, for_node_pool=True)
     flags.AddEnableAutoUpgradeFlag(node_management_group, for_node_pool=True)
+
     autoscaling_group = flags.AddClusterAutoscalingFlags(group, hidden=False)
     flags.AddNodePoolAutoprovisioningFlag(autoscaling_group, hidden=True)
 
+    flags.AddWorkloadMetadataFromNodeFlag(group)
+
+    flags.AddNodePoolLocationsFlag(group)
+
   def ParseUpdateNodePoolOptions(self, args):
     ops = api_adapter.UpdateNodePoolOptions(
         enable_autorepair=args.enable_autorepair,
@@ -166,7 +176,9 @@ class UpdateAlpha(Update):
         enable_autoscaling=args.enable_autoscaling,
         max_nodes=args.max_nodes,
         min_nodes=args.min_nodes,
-        enable_autoprovisioning=args.enable_autoprovisioning)
+        enable_autoprovisioning=args.enable_autoprovisioning,
+        workload_metadata_from_node=args.workload_metadata_from_node,
+        node_locations=args.node_locations)
     return ops
 
 
