@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2015 Google Inc. All Rights Reserved.
+# Copyright 2015 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,10 +12,12 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-"""gcloud dns dnskeys describe command."""
+"""gcloud dns dns-keys describe command."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.dns import dns_keys
 from googlecloudsdk.core import properties
@@ -28,7 +30,7 @@ class DescribeBase(object):
 
   @staticmethod
   def Args(parser):
-    dns_keys.AddDescribeFlags(parser)
+    dns_keys.AddDescribeFlags(parser, is_beta=True)
 
   def Run(self, args):
     keys = dns_keys.Keys.FromApiVersion(self.GetApiVersion())
