@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2018 Google Inc. All Rights Reserved.
+# Copyright 2018 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -213,4 +213,4 @@ class RunBeta(Run):
   @staticmethod
   def Args(parser):
     super(RunBeta, RunBeta).Args(parser)
-    arg_util.AddCommonBetaTestRunArgs(parser)
+    arg_util.AddBetaArgs(parser)
