@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2019 Google Inc. All Rights Reserved.
+# Copyright 2019 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,16 +18,17 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
 
-from googlecloudsdk.calliope import base
+from googlecloudsdk.command_lib.run import commands
 from googlecloudsdk.command_lib.run import connection_context
 from googlecloudsdk.command_lib.run import flags
+from googlecloudsdk.command_lib.run import pretty_print
 from googlecloudsdk.command_lib.run import resource_args
 from googlecloudsdk.command_lib.run import serverless_operations
 from googlecloudsdk.command_lib.util.concepts import concept_parsers
 from googlecloudsdk.command_lib.util.concepts import presentation_specs
 
 
-class List(base.ListCommand):
+class List(commands.List):
   """Lists domain mappings."""
 
   detailed_help = {
@@ -41,9 +42,11 @@ class List(base.ListCommand):
           """,
   }
 
-  @staticmethod
-  def Args(parser):
+  @classmethod
+  def Args(cls, parser):
     flags.AddRegionArgWithDefault(parser)
+    flags.AddPlatformArg(parser)
+    flags.AddKubeconfigFlags(parser)
     namespace_presentation = presentation_specs.ResourcePresentationSpec(
         '--namespace',
         resource_args.GetNamespaceResourceSpec(),
@@ -55,13 +58,16 @@ class List(base.ListCommand):
         namespace_presentation]).AddToParser(parser)
     parser.display_info.AddFormat(
         """table(
+        {ready_column},
+        metadata.name:label=DOMAIN,
         route_name:label=SERVICE,
-        region:label=REGION,
-        metadata.name:label=DOMAIN)""")
+        region:label=REGION)""".format(ready_column=pretty_print.READY_COLUMN))
+    parser.display_info.AddUriFunc(cls._GetResourceUri)
 
   def Run(self, args):
     """List available domain mappings."""
     conn_context = connection_context.GetConnectionContext(args)
     namespace_ref = args.CONCEPTS.namespace.Parse()
     with serverless_operations.Connect(conn_context) as client:
-      return client.ListDomainMappings(namespace_ref)
+      self.SetCompleteApiEndpoint(conn_context.endpoint)
+      return commands.SortByName(client.ListDomainMappings(namespace_ref))
