@@ -70,6 +70,7 @@ class Update(base.Command):
     flags.AddEndpointVisibilityEnum(parser)
     flags.AddAllowUnauthenticatedFlag(parser)
     flags.AddServiceAccountFlag(parser)
+    flags.AddRevisionSuffixArg(parser)
     concept_parsers.ConceptParser([
         resource_args.CLUSTER_PRESENTATION,
         service_presentation]).AddToParser(parser)
@@ -82,21 +83,20 @@ class Update(base.Command):
     Args:
       args: Args!
     """
+    changes = flags.GetConfigurationChanges(args)
+    endpoint_visibility = flags.GetEndpointVisibility(args)
+    allow_unauth = flags.GetAllowUnauthenticated(args)
+    if not changes and endpoint_visibility is None and allow_unauth is None:
+      raise exceptions.NoConfigurationChangeError(
+          'No configuration change requested. '
+          'Did you mean to include the flags `--update-env-vars`, '
+          '`--memory`, `--concurrency`, `--timeout`, `--connectivity`, '
+          'or `--allow-unauthenticated`?')
+
     conn_context = connection_context.GetConnectionContext(args)
     service_ref = flags.GetService(args)
 
     with serverless_operations.Connect(conn_context) as client:
-      changes = flags.GetConfigurationChanges(args)
-      endpoint_visibility = flags.GetEndpointVisibility(args)
-      allow_unauth = None
-      if conn_context.supports_one_platform:
-        allow_unauth = flags.GetAllowUnauthenticated(args, client, service_ref)
-      if not changes and endpoint_visibility is None and allow_unauth is None:
-        raise exceptions.NoConfigurationChangeError(
-            'No configuration change requested. '
-            'Did you mean to include the flags `--update-env-vars`, '
-            '`--memory`, `--concurrency`, `--timeout`, `--connectivity`, '
-            'or `--allow-unauthenticated`?')
       deployment_stages = stages.ServiceStages(allow_unauth is not None)
       with progress_tracker.StagedProgressTracker(
           'Deploying...',
