@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2016 Google Inc. All Rights Reserved.
+# Copyright 2016 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,10 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """Updates the settings of a Cloud SQL instance."""
+
 from __future__ import absolute_import
 from __future__ import division
-
 from __future__ import unicode_literals
+
 from apitools.base.py import encoding
 
 from googlecloudsdk.api_lib.sql import api_util as common_api_util
@@ -42,17 +43,25 @@ class _Result(object):
     self.old = old
 
 
-def _PrintAndConfirmWarningMessage(args):
+def _PrintAndConfirmWarningMessage(args, database_version):
   """Print and confirm warning indicating the effect of applying the patch."""
   continue_msg = None
-  if any([
-      args.tier, args.database_flags, args.clear_database_flags,
-      args.enable_database_replication is not None
-  ]):
+  if any([args.tier, args.enable_database_replication is not None]):
     continue_msg = (
         'WARNING: This patch modifies a value that requires '
         'your instance to be restarted. Submitting this patch '
         'will immediately restart your instance if it\'s running.')
+  elif any([args.database_flags, args.clear_database_flags]):
+    is_postgres = api_util.InstancesV1Beta4.IsPostgresDatabaseVersion(
+        database_version)
+    database_type_fragment = 'postgres' if is_postgres else 'mysql'
+    flag_docs_url = 'https://cloud.google.com/sql/docs/{}/flags'.format(
+        database_type_fragment)
+    continue_msg = (
+        'WARNING: This patch modifies database flag values, which may require '
+        'your instance to be restarted. Check the list of supported flags - '
+        '{} - to see if your instance will be restarted when this patch '
+        'is submitted.'.format(flag_docs_url))
   else:
     if any([args.follow_gae_app, args.gce_zone]):
       continue_msg = ('WARNING: This patch modifies the zone your instance '
@@ -64,7 +73,7 @@ def _PrintAndConfirmWarningMessage(args):
     raise exceptions.CancelledError('canceled by the user.')
 
 
-def _GetConfirmedClearedFields(args, patch_instance):
+def _GetConfirmedClearedFields(args, patch_instance, original_instance):
   """Clear fields according to args and confirm with user."""
   cleared_fields = []
 
@@ -81,7 +90,7 @@ def _GetConfirmedClearedFields(args, patch_instance):
       encoding.MessageToJson(patch_instance, include_fields=cleared_fields) +
       '\n')
 
-  _PrintAndConfirmWarningMessage(args)
+  _PrintAndConfirmWarningMessage(args, original_instance.databaseVersion)
 
   return cleared_fields
 
@@ -144,11 +153,9 @@ def AddBaseArgs(parser):
       help=('First Generation instances only. The App Engine app '
             'this instance should follow. It must be in the same region as '
             'the instance. WARNING: Instance may be restarted.'))
-  parser.add_argument(
-      '--gce-zone',
-      required=False,
-      help=('The preferred Compute Engine zone (e.g. us-central1-a, '
-            'us-central1-b, etc.). WARNING: Instance may be restarted.'))
+  flags.AddZone(parser, help_text=(
+      'Preferred Compute Engine zone (e.g. us-central1-a, '
+      'us-central1-b, etc.). WARNING: Instance may be restarted.'))
   parser.add_argument(
       'instance',
       completer=flags.InstanceCompleter,
@@ -176,21 +183,13 @@ def AddBaseArgs(parser):
             'over IP.'))
   flags.AddStorageAutoIncrease(parser)
   flags.AddStorageSize(parser)
-  parser.add_argument(
-      '--tier',
-      '-t',
-      required=False,
-      help=('The tier for this instance. For Second Generation instances, '
-            'TIER is the instance\'s machine type (e.g., db-n1-standard-1). '
-            'For PostgreSQL instances, only shared-core machine types '
-            '(e.g., db-f1-micro) apply. A complete list of tiers is '
-            'available here: https://cloud.google.com/sql/pricing. WARNING: '
-            'Instance will be restarted.'))
+  flags.AddTier(parser, is_patch=True)
 
 
 def AddBetaArgs(parser):
   """Adds beta args and flags to the parser."""
   flags.AddInstanceResizeLimit(parser)
+  flags.AddNetwork(parser)
   labels_util.AddUpdateLabelsFlags(parser, enable_clear=True)
 
 
@@ -239,7 +238,13 @@ def RunBasePatchCommand(args, release_track):
   patch_instance.project = instance_ref.project
   patch_instance.name = instance_ref.instance
 
-  cleared_fields = _GetConfirmedClearedFields(args, patch_instance)
+  # TODO(b/122660263): Remove when V1 instances are no longer supported.
+  # V1 deprecation notice.
+  if api_util.IsInstanceV1(original_instance_resource):
+    command_util.ShowV1DeprecationWarning()
+
+  cleared_fields = _GetConfirmedClearedFields(args, patch_instance,
+                                              original_instance_resource)
   # beta only
   if args.maintenance_window_any:
     cleared_fields.append('settings.maintenanceWindow')
@@ -285,7 +290,7 @@ class Patch(base.UpdateCommand):
     AddBaseArgs(parser)
 
 
-@base.ReleaseTracks(base.ReleaseTrack.BETA)
+@base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.ALPHA)
 class PatchBeta(base.UpdateCommand):
   """Updates the settings of a Cloud SQL instance."""
 
@@ -297,18 +302,3 @@ class PatchBeta(base.UpdateCommand):
     """Args is called by calliope to gather arguments for this command."""
     AddBaseArgs(parser)
     AddBetaArgs(parser)
-
-
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
-class PatchAlpha(base.UpdateCommand):
-  """Updates the settings of a Cloud SQL instance."""
-
-  def Run(self, args):
-    return RunBasePatchCommand(args, self.ReleaseTrack())
-
-  @staticmethod
-  def Args(parser):
-    """Args is called by calliope to gather arguments for this command."""
-    AddBaseArgs(parser)
-    AddBetaArgs(parser)
-    flags.AddNetwork(parser)
