@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2015 Google Inc. All Rights Reserved.
+# Copyright 2015 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -40,13 +40,7 @@ class Startup(base.TopicCommand):
       * python3
 
   Currently `gcloud` requires Python version 2.7.x and there is experimental
-  support for 3.4 and up. All `gcloud` commands work under Python 3 except
-  for the following command groups:
-
-      * `gcloud app`
-      * `gcloud datastore`
-      * `gcloud scheduler`
-      * `gcloud tasks`
+  support for 3.4 and up.
 
   Other Python tools shipped in the Cloud SDK do not yet support Python 3,
   including:
