@@ -15,6 +15,9 @@
 """Gsutil API delegator for interacting with cloud storage providers."""
 
 from __future__ import absolute_import
+from __future__ import print_function
+from __future__ import division
+from __future__ import unicode_literals
 
 import boto
 from boto import config
@@ -41,9 +44,16 @@ class CloudApiDelegator(CloudApi):
   multiple threads is unsafe.
   """
 
-  def __init__(self, bucket_storage_uri_class, gsutil_api_map, logger,
-               status_queue, provider=None, debug=0, trace_token=None,
-               perf_trace_token=None):
+  def __init__(self,
+               bucket_storage_uri_class,
+               gsutil_api_map,
+               logger,
+               status_queue,
+               provider=None,
+               debug=0,
+               trace_token=None,
+               perf_trace_token=None,
+               user_project=None):
     """Performs necessary setup for delegating cloud storage requests.
 
     This function has different arguments than the gsutil Cloud API __init__
@@ -61,12 +71,16 @@ class CloudApiDelegator(CloudApi):
       debug: Debug level for the API implementation (0..3).
       trace_token: Apiary trace token to pass to API.
       perf_trace_token: Performance trace token to use when making API calls.
+      user_project: Project to be billed for this project.
     """
-    super(CloudApiDelegator, self).__init__(bucket_storage_uri_class, logger,
+    super(CloudApiDelegator, self).__init__(bucket_storage_uri_class,
+                                            logger,
                                             status_queue,
-                                            provider=provider, debug=debug,
+                                            provider=provider,
+                                            debug=debug,
                                             trace_token=trace_token,
-                                            perf_trace_token=perf_trace_token)
+                                            perf_trace_token=perf_trace_token,
+                                            user_project=user_project)
     self.api_map = gsutil_api_map
     self.prefer_api = boto.config.get('GSUtil', 'prefer_api', '').upper()
     self.loaded_apis = {}
@@ -102,7 +116,6 @@ class CloudApiDelegator(CloudApi):
     if api_selector not in self.loaded_apis[provider]:
       # Need to load the API.
       self._LoadApi(provider, api_selector)
-
     return self.loaded_apis[provider][api_selector]
 
   def _LoadApi(self, provider, api_selector):
@@ -127,7 +140,8 @@ class CloudApiDelegator(CloudApi):
             provider=provider,
             debug=self.debug,
             trace_token=self.trace_token,
-            perf_trace_token=self.perf_trace_token))
+            perf_trace_token=self.perf_trace_token,
+            user_project=self.user_project))
 
   def GetApiSelector(self, provider=None):
     """Returns a cs_api_map.ApiSelector based on input and configuration.
@@ -159,20 +173,20 @@ class CloudApiDelegator(CloudApi):
     using_gs_hmac = (
         provider == 'gs' and
         not config.has_option('Credentials', 'gs_oauth2_refresh_token') and
-        not (config.has_option('Credentials', 'gs_service_client_id')
-             and config.has_option('Credentials', 'gs_service_key_file')) and
-        (config.has_option('Credentials', 'gs_access_key_id')
-         and config.has_option('Credentials', 'gs_secret_access_key')))
+        not (config.has_option('Credentials', 'gs_service_client_id') and
+             config.has_option('Credentials', 'gs_service_key_file')) and
+        (config.has_option('Credentials', 'gs_access_key_id') and
+         config.has_option('Credentials', 'gs_secret_access_key')))
 
-    configured_encryption = (
-        provider == 'gs' and
-        (config.has_option('GSUtil', 'encryption_key') or
-         config.has_option('GSUtil', 'decryption_key1')))
+    configured_encryption = (provider == 'gs' and
+                             (config.has_option('GSUtil', 'encryption_key') or
+                              config.has_option('GSUtil', 'decryption_key1')))
 
     if using_gs_hmac and configured_encryption:
       raise CommandException(
           'gsutil does not support HMAC credentials with customer-supplied '
-          'encryption keys. Please generate and include non-HMAC credentials '
+          'encryption keys (CSEK) or customer-managed KMS encryption keys '
+          '(CMEK). Please generate and include non-HMAC credentials '
           'in your .boto configuration file, or to access public encrypted '
           'objects, remove your HMAC credentials.')
     # If we have only HMAC credentials for Google Cloud Storage, we must use
@@ -184,7 +198,7 @@ class CloudApiDelegator(CloudApi):
     # every HTTP call.
     elif using_gs_hmac:
       api = ApiSelector.XML
-    # Customer-supplied encryption keys are currently only supported in the
+    # CSEK and CMEK encryption keys are currently only supported in the
     # JSON API implementation (GcsJsonApi). We can't stop XML API users from
     # interacting with encrypted objects, since we don't know the object is
     # encrypted until after the API call is made, but if they specify
@@ -192,8 +206,8 @@ class CloudApiDelegator(CloudApi):
     elif configured_encryption:
       api = ApiSelector.JSON
     # Try to force the user's preference to a supported API.
-    elif self.prefer_api in (self.api_map[ApiMapConstants.SUPPORT_MAP]
-                             [selected_provider]):
+    elif self.prefer_api in (
+        self.api_map[ApiMapConstants.SUPPORT_MAP][selected_provider]):
       api = self.prefer_api
     return api
 
@@ -211,147 +225,298 @@ class CloudApiDelegator(CloudApi):
     return self._GetApi(provider).ListBuckets(project_id=project_id,
                                               fields=fields)
 
-  def PatchBucket(self, bucket_name, metadata, canned_acl=None,
-                  canned_def_acl=None, preconditions=None, provider=None,
+  def PatchBucket(self,
+                  bucket_name,
+                  metadata,
+                  canned_acl=None,
+                  canned_def_acl=None,
+                  preconditions=None,
+                  provider=None,
                   fields=None):
-    return self._GetApi(provider).PatchBucket(
-        bucket_name, metadata, canned_acl=canned_acl,
-        canned_def_acl=canned_def_acl, preconditions=preconditions,
-        fields=fields)
+    return self._GetApi(provider).PatchBucket(bucket_name,
+                                              metadata,
+                                              canned_acl=canned_acl,
+                                              canned_def_acl=canned_def_acl,
+                                              preconditions=preconditions,
+                                              fields=fields)
 
-  def CreateBucket(self, bucket_name, project_id=None, metadata=None,
-                   provider=None, fields=None):
-    return self._GetApi(provider).CreateBucket(
-        bucket_name, project_id=project_id, metadata=metadata, fields=fields)
+  def LockRetentionPolicy(self, bucket_name, metageneration, provider=None):
+    return self._GetApi(provider).LockRetentionPolicy(bucket_name,
+                                                      metageneration,
+                                                      provider=provider)
+
+  def CreateBucket(self,
+                   bucket_name,
+                   project_id=None,
+                   metadata=None,
+                   provider=None,
+                   fields=None):
+    return self._GetApi(provider).CreateBucket(bucket_name,
+                                               project_id=project_id,
+                                               metadata=metadata,
+                                               fields=fields)
 
   def DeleteBucket(self, bucket_name, preconditions=None, provider=None):
     return self._GetApi(provider).DeleteBucket(bucket_name,
                                                preconditions=preconditions)
 
-  def GetObjectIamPolicy(self, bucket_name, object_name,
-                         generation=None, provider=None, fields=None):
-    return self._GetApi(provider).GetObjectIamPolicy(
-        bucket_name, object_name, generation, fields=fields)
+  def GetObjectIamPolicy(self,
+                         bucket_name,
+                         object_name,
+                         generation=None,
+                         provider=None,
+                         fields=None):
+    return self._GetApi(provider).GetObjectIamPolicy(bucket_name,
+                                                     object_name,
+                                                     generation,
+                                                     fields=fields)
 
-  def SetObjectIamPolicy(self, bucket_name, object_name, policy,
-                         generation=None, provider=None):
-    return self._GetApi(provider).SetObjectIamPolicy(
-        bucket_name, object_name, policy, generation)
+  def SetObjectIamPolicy(self,
+                         bucket_name,
+                         object_name,
+                         policy,
+                         generation=None,
+                         provider=None):
+    return self._GetApi(provider).SetObjectIamPolicy(bucket_name, object_name,
+                                                     policy, generation)
 
-  def ListObjects(self, bucket_name, prefix=None, delimiter=None,
-                  all_versions=None, provider=None, fields=None):
-    return self._GetApi(provider).ListObjects(
-        bucket_name, prefix=prefix, delimiter=delimiter,
-        all_versions=all_versions, fields=fields)
+  def ListObjects(self,
+                  bucket_name,
+                  prefix=None,
+                  delimiter=None,
+                  all_versions=None,
+                  provider=None,
+                  fields=None):
+    return self._GetApi(provider).ListObjects(bucket_name,
+                                              prefix=prefix,
+                                              delimiter=delimiter,
+                                              all_versions=all_versions,
+                                              fields=fields)
 
-  def GetObjectMetadata(self, bucket_name, object_name, generation=None,
-                        provider=None, fields=None):
-    return self._GetApi(provider).GetObjectMetadata(
-        bucket_name, object_name, generation=generation, fields=fields)
+  def GetObjectMetadata(self,
+                        bucket_name,
+                        object_name,
+                        generation=None,
+                        provider=None,
+                        fields=None):
+    return self._GetApi(provider).GetObjectMetadata(bucket_name,
+                                                    object_name,
+                                                    generation=generation,
+                                                    fields=fields)
 
-  def PatchObjectMetadata(self, bucket_name, object_name, metadata,
-                          canned_acl=None, generation=None, preconditions=None,
-                          provider=None, fields=None):
+  def PatchObjectMetadata(self,
+                          bucket_name,
+                          object_name,
+                          metadata,
+                          canned_acl=None,
+                          generation=None,
+                          preconditions=None,
+                          provider=None,
+                          fields=None):
     return self._GetApi(provider).PatchObjectMetadata(
-        bucket_name, object_name, metadata, canned_acl=canned_acl,
-        generation=generation, preconditions=preconditions, fields=fields)
-
-  def GetObjectMedia(
-      self, bucket_name, object_name, download_stream, provider=None,
-      generation=None, object_size=None,
-      compressed_encoding=False,
-      download_strategy=CloudApi.DownloadStrategy.ONE_SHOT,
-      start_byte=0, end_byte=None, progress_callback=None,
-      serialization_data=None, digesters=None, decryption_tuple=None):
-    return self._GetApi(provider).GetObjectMedia(
-        bucket_name, object_name, download_stream,
-        compressed_encoding=compressed_encoding,
-        download_strategy=download_strategy, start_byte=start_byte,
-        end_byte=end_byte, generation=generation, object_size=object_size,
-        progress_callback=progress_callback,
-        serialization_data=serialization_data, digesters=digesters,
-        decryption_tuple=decryption_tuple)
-
-  def UploadObject(self, upload_stream, object_metadata, size=None,
-                   canned_acl=None, preconditions=None, progress_callback=None,
-                   encryption_tuple=None, provider=None, fields=None):
-    return self._GetApi(provider).UploadObject(
-        upload_stream, object_metadata, size=size, canned_acl=canned_acl,
-        preconditions=preconditions, progress_callback=progress_callback,
-        encryption_tuple=encryption_tuple, fields=fields)
-
-  def UploadObjectStreaming(self, upload_stream, object_metadata,
-                            canned_acl=None, preconditions=None,
-                            progress_callback=None, encryption_tuple=None,
-                            provider=None, fields=None):
-    return self._GetApi(provider).UploadObjectStreaming(
-        upload_stream, object_metadata, canned_acl=canned_acl,
-        preconditions=preconditions, progress_callback=progress_callback,
-        encryption_tuple=encryption_tuple, fields=fields)
-
-  def UploadObjectResumable(
-      self, upload_stream, object_metadata, canned_acl=None, preconditions=None,
-      size=None, serialization_data=None, tracker_callback=None,
-      progress_callback=None, encryption_tuple=None, provider=None,
-      fields=None):
-    return self._GetApi(provider).UploadObjectResumable(
-        upload_stream, object_metadata, canned_acl=canned_acl,
-        preconditions=preconditions, size=size,
-        serialization_data=serialization_data,
-        tracker_callback=tracker_callback, progress_callback=progress_callback,
-        encryption_tuple=encryption_tuple, fields=fields)
-
-  def CopyObject(self, src_obj_metadata, dst_obj_metadata, src_generation=None,
-                 canned_acl=None, preconditions=None, progress_callback=None,
-                 max_bytes_per_call=None, encryption_tuple=None,
-                 decryption_tuple=None, provider=None, fields=None):
-    return self._GetApi(provider).CopyObject(
-        src_obj_metadata, dst_obj_metadata, src_generation=src_generation,
-        canned_acl=canned_acl, preconditions=preconditions,
-        progress_callback=progress_callback,
-        max_bytes_per_call=max_bytes_per_call,
-        encryption_tuple=encryption_tuple, decryption_tuple=decryption_tuple,
+        bucket_name,
+        object_name,
+        metadata,
+        canned_acl=canned_acl,
+        generation=generation,
+        preconditions=preconditions,
         fields=fields)
 
-  def ComposeObject(self, src_objs_metadata, dst_obj_metadata,
-                    preconditions=None, encryption_tuple=None, provider=None,
+  def GetObjectMedia(self,
+                     bucket_name,
+                     object_name,
+                     download_stream,
+                     provider=None,
+                     generation=None,
+                     object_size=None,
+                     compressed_encoding=False,
+                     download_strategy=CloudApi.DownloadStrategy.ONE_SHOT,
+                     start_byte=0,
+                     end_byte=None,
+                     progress_callback=None,
+                     serialization_data=None,
+                     digesters=None,
+                     decryption_tuple=None):
+    return self._GetApi(provider).GetObjectMedia(
+        bucket_name,
+        object_name,
+        download_stream,
+        compressed_encoding=compressed_encoding,
+        download_strategy=download_strategy,
+        start_byte=start_byte,
+        end_byte=end_byte,
+        generation=generation,
+        object_size=object_size,
+        progress_callback=progress_callback,
+        serialization_data=serialization_data,
+        digesters=digesters,
+        decryption_tuple=decryption_tuple)
+
+  def UploadObject(self,
+                   upload_stream,
+                   object_metadata,
+                   size=None,
+                   canned_acl=None,
+                   preconditions=None,
+                   progress_callback=None,
+                   encryption_tuple=None,
+                   provider=None,
+                   fields=None,
+                   gzip_encoded=False):
+    return self._GetApi(provider).UploadObject(
+        upload_stream,
+        object_metadata,
+        size=size,
+        canned_acl=canned_acl,
+        preconditions=preconditions,
+        progress_callback=progress_callback,
+        encryption_tuple=encryption_tuple,
+        fields=fields,
+        gzip_encoded=gzip_encoded)
+
+  def UploadObjectStreaming(self,
+                            upload_stream,
+                            object_metadata,
+                            canned_acl=None,
+                            preconditions=None,
+                            progress_callback=None,
+                            encryption_tuple=None,
+                            provider=None,
+                            fields=None,
+                            gzip_encoded=False):
+    return self._GetApi(provider).UploadObjectStreaming(
+        upload_stream,
+        object_metadata,
+        canned_acl=canned_acl,
+        preconditions=preconditions,
+        progress_callback=progress_callback,
+        encryption_tuple=encryption_tuple,
+        fields=fields,
+        gzip_encoded=gzip_encoded)
+
+  def UploadObjectResumable(self,
+                            upload_stream,
+                            object_metadata,
+                            canned_acl=None,
+                            preconditions=None,
+                            size=None,
+                            serialization_data=None,
+                            tracker_callback=None,
+                            progress_callback=None,
+                            encryption_tuple=None,
+                            provider=None,
+                            fields=None,
+                            gzip_encoded=False):
+    return self._GetApi(provider).UploadObjectResumable(
+        upload_stream,
+        object_metadata,
+        canned_acl=canned_acl,
+        preconditions=preconditions,
+        size=size,
+        serialization_data=serialization_data,
+        tracker_callback=tracker_callback,
+        progress_callback=progress_callback,
+        encryption_tuple=encryption_tuple,
+        fields=fields,
+        gzip_encoded=gzip_encoded)
+
+  def CopyObject(self,
+                 src_obj_metadata,
+                 dst_obj_metadata,
+                 src_generation=None,
+                 canned_acl=None,
+                 preconditions=None,
+                 progress_callback=None,
+                 max_bytes_per_call=None,
+                 encryption_tuple=None,
+                 decryption_tuple=None,
+                 provider=None,
+                 fields=None):
+    return self._GetApi(provider).CopyObject(
+        src_obj_metadata,
+        dst_obj_metadata,
+        src_generation=src_generation,
+        canned_acl=canned_acl,
+        preconditions=preconditions,
+        progress_callback=progress_callback,
+        max_bytes_per_call=max_bytes_per_call,
+        encryption_tuple=encryption_tuple,
+        decryption_tuple=decryption_tuple,
+        fields=fields)
+
+  def ComposeObject(self,
+                    src_objs_metadata,
+                    dst_obj_metadata,
+                    preconditions=None,
+                    encryption_tuple=None,
+                    provider=None,
                     fields=None):
     return self._GetApi(provider).ComposeObject(
-        src_objs_metadata, dst_obj_metadata, preconditions=preconditions,
-        encryption_tuple=encryption_tuple, fields=fields)
+        src_objs_metadata,
+        dst_obj_metadata,
+        preconditions=preconditions,
+        encryption_tuple=encryption_tuple,
+        fields=fields)
 
-  def DeleteObject(self, bucket_name, object_name, preconditions=None,
-                   generation=None, provider=None):
-    return self._GetApi(provider).DeleteObject(
-        bucket_name, object_name, preconditions=preconditions,
-        generation=generation)
+  def DeleteObject(self,
+                   bucket_name,
+                   object_name,
+                   preconditions=None,
+                   generation=None,
+                   provider=None):
+    return self._GetApi(provider).DeleteObject(bucket_name,
+                                               object_name,
+                                               preconditions=preconditions,
+                                               generation=generation)
 
-  def WatchBucket(self, bucket_name, address, channel_id, token=None,
-                  provider=None, fields=None):
-    return self._GetApi(provider).WatchBucket(
-        bucket_name, address, channel_id, token=token, fields=fields)
+  def WatchBucket(self,
+                  bucket_name,
+                  address,
+                  channel_id,
+                  token=None,
+                  provider=None,
+                  fields=None):
+    return self._GetApi(provider).WatchBucket(bucket_name,
+                                              address,
+                                              channel_id,
+                                              token=token,
+                                              fields=fields)
 
   def StopChannel(self, channel_id, resource_id, provider=None):
     return self._GetApi(provider).StopChannel(channel_id, resource_id)
 
+  def ListChannels(self, bucket_name, provider=None):
+    return self._GetApi(provider).ListChannels(bucket_name)
+
   def GetProjectServiceAccount(self, project_number, provider=None):
     return self._GetApi(provider).GetProjectServiceAccount(project_number)
 
-  def CreateNotificationConfig(
-      self, bucket_name, pubsub_topic, payload_format, event_types=None,
-      custom_attributes=None, object_name_prefix=None, provider=None):
+  def CreateNotificationConfig(self,
+                               bucket_name,
+                               pubsub_topic,
+                               payload_format,
+                               event_types=None,
+                               custom_attributes=None,
+                               object_name_prefix=None,
+                               provider=None):
     return self._GetApi(provider).CreateNotificationConfig(
         bucket_name, pubsub_topic, payload_format, event_types,
         custom_attributes, object_name_prefix)
 
-  def DeleteNotificationConfig(
-      self, bucket_name, notification, provider=None):
+  def DeleteNotificationConfig(self, bucket_name, notification, provider=None):
     return self._GetApi(provider).DeleteNotificationConfig(
         bucket_name, notification)
 
   def ListNotificationConfigs(self, bucket_name, provider=None):
     return self._GetApi(provider).ListNotificationConfigs(bucket_name)
 
+  def ListBucketAccessControls(self, bucket_name, provider=None):
+    return self._GetApi(provider).ListBucketAccessControls(bucket_name)
+
+  def ListObjectAccessControls(self, bucket_name, object_name, provider=None):
+    return self._GetApi(provider).ListObjectAccessControls(
+        bucket_name, object_name)
+
   def XmlPassThroughGetAcl(self, storage_url, def_obj_acl=False, provider=None):
     """XML compatibility function for getting ACLs.
 
@@ -371,8 +536,12 @@ class CloudApiDelegator(CloudApi):
     return self._GetApi(provider).XmlPassThroughGetAcl(storage_url,
                                                        def_obj_acl=def_obj_acl)
 
-  def XmlPassThroughSetAcl(self, acl_text, storage_url, canned=True,
-                           def_obj_acl=False, provider=None):
+  def XmlPassThroughSetAcl(self,
+                           acl_text,
+                           storage_url,
+                           canned=True,
+                           def_obj_acl=False,
+                           provider=None):
     """XML compatibility function for setting ACLs.
 
     Args:
@@ -390,8 +559,10 @@ class CloudApiDelegator(CloudApi):
     Returns:
       None.
     """
-    self._GetApi(provider).XmlPassThroughSetAcl(
-        acl_text, storage_url, canned=canned, def_obj_acl=def_obj_acl)
+    self._GetApi(provider).XmlPassThroughSetAcl(acl_text,
+                                                storage_url,
+                                                canned=canned,
+                                                def_obj_acl=def_obj_acl)
 
   def XmlPassThroughGetCors(self, storage_url, provider=None):
     """XML compatibility function for getting CORS configuration on a bucket.
@@ -445,9 +616,11 @@ class CloudApiDelegator(CloudApi):
     """
     return self._GetApi(provider).XmlPassThroughGetLifecycle(storage_url)
 
-  def XmlPassThroughSetLifecycle(self, lifecycle_text, storage_url,
+  def XmlPassThroughSetLifecycle(self,
+                                 lifecycle_text,
+                                 storage_url,
                                  provider=None):
-    """XML compatibility function for setting CORS configuration on a bucket.
+    """XML compatibility function for setting lifecycle config on a bucket.
 
     Args:
       lifecycle_text: Raw lifecycle configuration XML string.
@@ -482,6 +655,45 @@ class CloudApiDelegator(CloudApi):
     """
     return self._GetApi(provider).XmlPassThroughGetLogging(storage_url)
 
+  def XmlPassThroughSetTagging(self, tags_text, storage_url, provider=None):
+    """XML compatibility function for setting tagging configuration on a bucket.
+
+    This passthrough provides support for setting a tagging configuration
+    (equivalent to a label configuration) on a cloud bucket.
+
+    Args:
+      tags_text: Raw tagging configuration XML string.
+      storage_url: StorageUrl object.
+      provider: Cloud storage provider to connect to.  If not present,
+                class-wide default is used.
+
+    Raises:
+      ArgumentException for errors during input validation.
+      ServiceException for errors interacting with cloud storage providers.
+
+    Returns:
+      None.
+    """
+    return self._GetApi(provider).XmlPassThroughSetTagging(
+        tags_text, storage_url)
+
+  def XmlPassThroughGetTagging(self, storage_url, provider=None):
+    """XML compatibility function for getting tagging configuration on a bucket.
+
+    Args:
+      storage_url: StorageUrl object.
+      provider: Cloud storage provider to connect to.  If not present,
+                class-wide default is used.
+
+    Raises:
+      ArgumentException for errors during input validation.
+      ServiceException for errors interacting with cloud storage providers.
+
+    Returns:
+      Tagging configuration XML for the bucket specified by storage_url.
+    """
+    return self._GetApi(provider).XmlPassThroughGetTagging(storage_url)
+
   def XmlPassThroughGetWebsite(self, storage_url, provider=None):
     """XML compatibility function for getting website configuration on a bucket.
 
@@ -498,4 +710,3 @@ class CloudApiDelegator(CloudApi):
       Website configuration XML for the bucket specified by storage_url.
     """
     return self._GetApi(provider).XmlPassThroughGetWebsite(storage_url)
-
